# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'Endpoints',
]

@pulumi.output_type
class Endpoints(dict):
    def __init__(__self__, *,
                 apps: Optional[str] = None,
                 apps_rules: Optional[str] = None,
                 auth_servers: Optional[str] = None,
                 privileges: Optional[str] = None,
                 risk_rules: Optional[str] = None,
                 roles: Optional[str] = None,
                 users: Optional[str] = None,
                 users_v1: Optional[str] = None):
        """
        :param str apps: Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        :param str apps_rules: Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        :param str auth_servers: Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        :param str privileges: Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        :param str risk_rules: Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        :param str roles: Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        :param str users: Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        :param str users_v1: Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        """
        if apps is not None:
            pulumi.set(__self__, "apps", apps)
        if apps_rules is not None:
            pulumi.set(__self__, "apps_rules", apps_rules)
        if auth_servers is not None:
            pulumi.set(__self__, "auth_servers", auth_servers)
        if privileges is not None:
            pulumi.set(__self__, "privileges", privileges)
        if risk_rules is not None:
            pulumi.set(__self__, "risk_rules", risk_rules)
        if roles is not None:
            pulumi.set(__self__, "roles", roles)
        if users is not None:
            pulumi.set(__self__, "users", users)
        if users_v1 is not None:
            pulumi.set(__self__, "users_v1", users_v1)

    @property
    @pulumi.getter
    def apps(self) -> Optional[str]:
        """
        Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        """
        return pulumi.get(self, "apps")

    @property
    @pulumi.getter(name="appsRules")
    def apps_rules(self) -> Optional[str]:
        """
        Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        """
        return pulumi.get(self, "apps_rules")

    @property
    @pulumi.getter(name="authServers")
    def auth_servers(self) -> Optional[str]:
        """
        Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        """
        return pulumi.get(self, "auth_servers")

    @property
    @pulumi.getter
    def privileges(self) -> Optional[str]:
        """
        Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        """
        return pulumi.get(self, "privileges")

    @property
    @pulumi.getter(name="riskRules")
    def risk_rules(self) -> Optional[str]:
        """
        Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        """
        return pulumi.get(self, "risk_rules")

    @property
    @pulumi.getter
    def roles(self) -> Optional[str]:
        """
        Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter
    def users(self) -> Optional[str]:
        """
        Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        """
        return pulumi.get(self, "users")

    @property
    @pulumi.getter(name="usersV1")
    def users_v1(self) -> Optional[str]:
        """
        Use this to override the resource endpoint URL (the default one or the one constructed from the `region`).
        """
        return pulumi.get(self, "users_v1")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 activated_at: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 company: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 department: Optional[pulumi.Input[str]] = None,
                 directory_id: Optional[pulumi.Input[int]] = None,
                 distinguished_name: Optional[pulumi.Input[str]] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 firstname: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[int]] = None,
                 invalid_login_attempts: Optional[pulumi.Input[int]] = None,
                 invitation_sent_at: Optional[pulumi.Input[str]] = None,
                 last_login: Optional[pulumi.Input[str]] = None,
                 lastname: Optional[pulumi.Input[str]] = None,
                 locked_until: Optional[pulumi.Input[str]] = None,
                 manager_ad_id: Optional[pulumi.Input[str]] = None,
                 manager_user_id: Optional[pulumi.Input[str]] = None,
                 member_of: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 password_algorithm: Optional[pulumi.Input[str]] = None,
                 password_changed_at: Optional[pulumi.Input[str]] = None,
                 password_confirmation: Optional[pulumi.Input[str]] = None,
                 phone: Optional[pulumi.Input[str]] = None,
                 preferred_locale_code: Optional[pulumi.Input[str]] = None,
                 role_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 salt: Optional[pulumi.Input[str]] = None,
                 samaccountname: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[int]] = None,
                 status: Optional[pulumi.Input[int]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 trusted_idp_id: Optional[pulumi.Input[int]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 userprincipalname: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[str] comment: Free text related to the user.
        :param pulumi.Input[str] company: The user's company.
        :param pulumi.Input[str] department: The user's department.
        :param pulumi.Input[int] directory_id: The ID of the OneLogin Directory of the user.
        :param pulumi.Input[str] distinguished_name: The distinguished name of the user.
        :param pulumi.Input[str] email: A valid email for the user.
        :param pulumi.Input[str] external_id: The ID of the user in an external directory.
        :param pulumi.Input[str] firstname: The user's first name.
        :param pulumi.Input[int] group_id: The ID of the Group in OneLogin that the user is assigned to.
        :param pulumi.Input[str] lastname: The user's last name.
        :param pulumi.Input[str] manager_ad_id: The ID of the user's manager in Active Directory.
        :param pulumi.Input[str] manager_user_id: The OneLogin User ID for the user's manager.
        :param pulumi.Input[str] member_of: The user's directory membership.
        :param pulumi.Input[str] password: The password to set for a user.
        :param pulumi.Input[str] password_algorithm: Use this when importing a password that's already hashed. Prepend the salt value to the cleartext password value before
               SHA-256-encoding it
        :param pulumi.Input[str] password_confirmation: Required if the password is being set.
        :param pulumi.Input[str] phone: The E.164 format phone number for a user.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] role_ids: A list of OneLogin Role IDs of the user
        :param pulumi.Input[str] salt: The salt value used with the password_algorithm.
        :param pulumi.Input[str] samaccountname: The user's Active Directory username.
        :param pulumi.Input[str] title: The user's job title.
        :param pulumi.Input[int] trusted_idp_id: The ID of the OneLogin Trusted IDP of the user.
        :param pulumi.Input[str] username: A username for the user.
        :param pulumi.Input[str] userprincipalname: The principle name of the user.
        """
        if activated_at is not None:
            pulumi.set(__self__, "activated_at", activated_at)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if company is not None:
            pulumi.set(__self__, "company", company)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if department is not None:
            pulumi.set(__self__, "department", department)
        if directory_id is not None:
            pulumi.set(__self__, "directory_id", directory_id)
        if distinguished_name is not None:
            pulumi.set(__self__, "distinguished_name", distinguished_name)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if firstname is not None:
            pulumi.set(__self__, "firstname", firstname)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if invalid_login_attempts is not None:
            pulumi.set(__self__, "invalid_login_attempts", invalid_login_attempts)
        if invitation_sent_at is not None:
            pulumi.set(__self__, "invitation_sent_at", invitation_sent_at)
        if last_login is not None:
            pulumi.set(__self__, "last_login", last_login)
        if lastname is not None:
            pulumi.set(__self__, "lastname", lastname)
        if locked_until is not None:
            pulumi.set(__self__, "locked_until", locked_until)
        if manager_ad_id is not None:
            pulumi.set(__self__, "manager_ad_id", manager_ad_id)
        if manager_user_id is not None:
            pulumi.set(__self__, "manager_user_id", manager_user_id)
        if member_of is not None:
            pulumi.set(__self__, "member_of", member_of)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if password_algorithm is not None:
            pulumi.set(__self__, "password_algorithm", password_algorithm)
        if password_changed_at is not None:
            pulumi.set(__self__, "password_changed_at", password_changed_at)
        if password_confirmation is not None:
            pulumi.set(__self__, "password_confirmation", password_confirmation)
        if phone is not None:
            pulumi.set(__self__, "phone", phone)
        if preferred_locale_code is not None:
            pulumi.set(__self__, "preferred_locale_code", preferred_locale_code)
        if role_ids is not None:
            pulumi.set(__self__, "role_ids", role_ids)
        if salt is not None:
            pulumi.set(__self__, "salt", salt)
        if samaccountname is not None:
            pulumi.set(__self__, "samaccountname", samaccountname)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if trusted_idp_id is not None:
            pulumi.set(__self__, "trusted_idp_id", trusted_idp_id)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if userprincipalname is not None:
            pulumi.set(__self__, "userprincipalname", userprincipalname)

    @property
    @pulumi.getter(name="activatedAt")
    def activated_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "activated_at")

    @activated_at.setter
    def activated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "activated_at", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        Free text related to the user.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter
    def company(self) -> Optional[pulumi.Input[str]]:
        """
        The user's company.
        """
        return pulumi.get(self, "company")

    @company.setter
    def company(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "company", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def department(self) -> Optional[pulumi.Input[str]]:
        """
        The user's department.
        """
        return pulumi.get(self, "department")

    @department.setter
    def department(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "department", value)

    @property
    @pulumi.getter(name="directoryId")
    def directory_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the OneLogin Directory of the user.
        """
        return pulumi.get(self, "directory_id")

    @directory_id.setter
    def directory_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "directory_id", value)

    @property
    @pulumi.getter(name="distinguishedName")
    def distinguished_name(self) -> Optional[pulumi.Input[str]]:
        """
        The distinguished name of the user.
        """
        return pulumi.get(self, "distinguished_name")

    @distinguished_name.setter
    def distinguished_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "distinguished_name", value)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[str]]:
        """
        A valid email for the user.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the user in an external directory.
        """
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter
    def firstname(self) -> Optional[pulumi.Input[str]]:
        """
        The user's first name.
        """
        return pulumi.get(self, "firstname")

    @firstname.setter
    def firstname(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "firstname", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the Group in OneLogin that the user is assigned to.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="invalidLoginAttempts")
    def invalid_login_attempts(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "invalid_login_attempts")

    @invalid_login_attempts.setter
    def invalid_login_attempts(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "invalid_login_attempts", value)

    @property
    @pulumi.getter(name="invitationSentAt")
    def invitation_sent_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "invitation_sent_at")

    @invitation_sent_at.setter
    def invitation_sent_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "invitation_sent_at", value)

    @property
    @pulumi.getter(name="lastLogin")
    def last_login(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "last_login")

    @last_login.setter
    def last_login(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_login", value)

    @property
    @pulumi.getter
    def lastname(self) -> Optional[pulumi.Input[str]]:
        """
        The user's last name.
        """
        return pulumi.get(self, "lastname")

    @lastname.setter
    def lastname(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lastname", value)

    @property
    @pulumi.getter(name="lockedUntil")
    def locked_until(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "locked_until")

    @locked_until.setter
    def locked_until(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "locked_until", value)

    @property
    @pulumi.getter(name="managerAdId")
    def manager_ad_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the user's manager in Active Directory.
        """
        return pulumi.get(self, "manager_ad_id")

    @manager_ad_id.setter
    def manager_ad_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "manager_ad_id", value)

    @property
    @pulumi.getter(name="managerUserId")
    def manager_user_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OneLogin User ID for the user's manager.
        """
        return pulumi.get(self, "manager_user_id")

    @manager_user_id.setter
    def manager_user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "manager_user_id", value)

    @property
    @pulumi.getter(name="memberOf")
    def member_of(self) -> Optional[pulumi.Input[str]]:
        """
        The user's directory membership.
        """
        return pulumi.get(self, "member_of")

    @member_of.setter
    def member_of(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "member_of", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        The password to set for a user.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="passwordAlgorithm")
    def password_algorithm(self) -> Optional[pulumi.Input[str]]:
        """
        Use this when importing a password that's already hashed. Prepend the salt value to the cleartext password value before
        SHA-256-encoding it
        """
        return pulumi.get(self, "password_algorithm")

    @password_algorithm.setter
    def password_algorithm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password_algorithm", value)

    @property
    @pulumi.getter(name="passwordChangedAt")
    def password_changed_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "password_changed_at")

    @password_changed_at.setter
    def password_changed_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password_changed_at", value)

    @property
    @pulumi.getter(name="passwordConfirmation")
    def password_confirmation(self) -> Optional[pulumi.Input[str]]:
        """
        Required if the password is being set.
        """
        return pulumi.get(self, "password_confirmation")

    @password_confirmation.setter
    def password_confirmation(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password_confirmation", value)

    @property
    @pulumi.getter
    def phone(self) -> Optional[pulumi.Input[str]]:
        """
        The E.164 format phone number for a user.
        """
        return pulumi.get(self, "phone")

    @phone.setter
    def phone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "phone", value)

    @property
    @pulumi.getter(name="preferredLocaleCode")
    def preferred_locale_code(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "preferred_locale_code")

    @preferred_locale_code.setter
    def preferred_locale_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "preferred_locale_code", value)

    @property
    @pulumi.getter(name="roleIds")
    def role_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        A list of OneLogin Role IDs of the user
        """
        return pulumi.get(self, "role_ids")

    @role_ids.setter
    def role_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "role_ids", value)

    @property
    @pulumi.getter
    def salt(self) -> Optional[pulumi.Input[str]]:
        """
        The salt value used with the password_algorithm.
        """
        return pulumi.get(self, "salt")

    @salt.setter
    def salt(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "salt", value)

    @property
    @pulumi.getter
    def samaccountname(self) -> Optional[pulumi.Input[str]]:
        """
        The user's Active Directory username.
        """
        return pulumi.get(self, "samaccountname")

    @samaccountname.setter
    def samaccountname(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "samaccountname", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        The user's job title.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter(name="trustedIdpId")
    def trusted_idp_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the OneLogin Trusted IDP of the user.
        """
        return pulumi.get(self, "trusted_idp_id")

    @trusted_idp_id.setter
    def trusted_idp_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "trusted_idp_id", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        A username for the user.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter
    def userprincipalname(self) -> Optional[pulumi.Input[str]]:
        """
        The principle name of the user.
        """
        return pulumi.get(self, "userprincipalname")

    @userprincipalname.setter
    def userprincipalname(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "userprincipalname", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 activated_at: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 company: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 department: Optional[pulumi.Input[str]] = None,
                 directory_id: Optional[pulumi.Input[int]] = None,
                 distinguished_name: Optional[pulumi.Input[str]] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 firstname: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[int]] = None,
                 invalid_login_attempts: Optional[pulumi.Input[int]] = None,
                 invitation_sent_at: Optional[pulumi.Input[str]] = None,
                 last_login: Optional[pulumi.Input[str]] = None,
                 lastname: Optional[pulumi.Input[str]] = None,
                 locked_until: Optional[pulumi.Input[str]] = None,
                 manager_ad_id: Optional[pulumi.Input[str]] = None,
                 manager_user_id: Optional[pulumi.Input[str]] = None,
                 member_of: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 password_algorithm: Optional[pulumi.Input[str]] = None,
                 password_changed_at: Optional[pulumi.Input[str]] = None,
                 password_confirmation: Optional[pulumi.Input[str]] = None,
                 phone: Optional[pulumi.Input[str]] = None,
                 preferred_locale_code: Optional[pulumi.Input[str]] = None,
                 role_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 salt: Optional[pulumi.Input[str]] = None,
                 samaccountname: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[int]] = None,
                 status: Optional[pulumi.Input[int]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 trusted_idp_id: Optional[pulumi.Input[int]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 userprincipalname: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[str] comment: Free text related to the user.
        :param pulumi.Input[str] company: The user's company.
        :param pulumi.Input[str] department: The user's department.
        :param pulumi.Input[int] directory_id: The ID of the OneLogin Directory of the user.
        :param pulumi.Input[str] distinguished_name: The distinguished name of the user.
        :param pulumi.Input[str] email: A valid email for the user.
        :param pulumi.Input[str] external_id: The ID of the user in an external directory.
        :param pulumi.Input[str] firstname: The user's first name.
        :param pulumi.Input[int] group_id: The ID of the Group in OneLogin that the user is assigned to.
        :param pulumi.Input[str] lastname: The user's last name.
        :param pulumi.Input[str] manager_ad_id: The ID of the user's manager in Active Directory.
        :param pulumi.Input[str] manager_user_id: The OneLogin User ID for the user's manager.
        :param pulumi.Input[str] member_of: The user's directory membership.
        :param pulumi.Input[str] password: The password to set for a user.
        :param pulumi.Input[str] password_algorithm: Use this when importing a password that's already hashed. Prepend the salt value to the cleartext password value before
               SHA-256-encoding it
        :param pulumi.Input[str] password_confirmation: Required if the password is being set.
        :param pulumi.Input[str] phone: The E.164 format phone number for a user.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] role_ids: A list of OneLogin Role IDs of the user
        :param pulumi.Input[str] salt: The salt value used with the password_algorithm.
        :param pulumi.Input[str] samaccountname: The user's Active Directory username.
        :param pulumi.Input[str] title: The user's job title.
        :param pulumi.Input[int] trusted_idp_id: The ID of the OneLogin Trusted IDP of the user.
        :param pulumi.Input[str] username: A username for the user.
        :param pulumi.Input[str] userprincipalname: The principle name of the user.
        """
        if activated_at is not None:
            pulumi.set(__self__, "activated_at", activated_at)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if company is not None:
            pulumi.set(__self__, "company", company)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if department is not None:
            pulumi.set(__self__, "department", department)
        if directory_id is not None:
            pulumi.set(__self__, "directory_id", directory_id)
        if distinguished_name is not None:
            pulumi.set(__self__, "distinguished_name", distinguished_name)
        if email is not None:
            pulumi.set(__self__, "email", email)
        if external_id is not None:
            pulumi.set(__self__, "external_id", external_id)
        if firstname is not None:
            pulumi.set(__self__, "firstname", firstname)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if invalid_login_attempts is not None:
            pulumi.set(__self__, "invalid_login_attempts", invalid_login_attempts)
        if invitation_sent_at is not None:
            pulumi.set(__self__, "invitation_sent_at", invitation_sent_at)
        if last_login is not None:
            pulumi.set(__self__, "last_login", last_login)
        if lastname is not None:
            pulumi.set(__self__, "lastname", lastname)
        if locked_until is not None:
            pulumi.set(__self__, "locked_until", locked_until)
        if manager_ad_id is not None:
            pulumi.set(__self__, "manager_ad_id", manager_ad_id)
        if manager_user_id is not None:
            pulumi.set(__self__, "manager_user_id", manager_user_id)
        if member_of is not None:
            pulumi.set(__self__, "member_of", member_of)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if password_algorithm is not None:
            pulumi.set(__self__, "password_algorithm", password_algorithm)
        if password_changed_at is not None:
            pulumi.set(__self__, "password_changed_at", password_changed_at)
        if password_confirmation is not None:
            pulumi.set(__self__, "password_confirmation", password_confirmation)
        if phone is not None:
            pulumi.set(__self__, "phone", phone)
        if preferred_locale_code is not None:
            pulumi.set(__self__, "preferred_locale_code", preferred_locale_code)
        if role_ids is not None:
            pulumi.set(__self__, "role_ids", role_ids)
        if salt is not None:
            pulumi.set(__self__, "salt", salt)
        if samaccountname is not None:
            pulumi.set(__self__, "samaccountname", samaccountname)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if trusted_idp_id is not None:
            pulumi.set(__self__, "trusted_idp_id", trusted_idp_id)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if userprincipalname is not None:
            pulumi.set(__self__, "userprincipalname", userprincipalname)

    @property
    @pulumi.getter(name="activatedAt")
    def activated_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "activated_at")

    @activated_at.setter
    def activated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "activated_at", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        Free text related to the user.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter
    def company(self) -> Optional[pulumi.Input[str]]:
        """
        The user's company.
        """
        return pulumi.get(self, "company")

    @company.setter
    def company(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "company", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def department(self) -> Optional[pulumi.Input[str]]:
        """
        The user's department.
        """
        return pulumi.get(self, "department")

    @department.setter
    def department(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "department", value)

    @property
    @pulumi.getter(name="directoryId")
    def directory_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the OneLogin Directory of the user.
        """
        return pulumi.get(self, "directory_id")

    @directory_id.setter
    def directory_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "directory_id", value)

    @property
    @pulumi.getter(name="distinguishedName")
    def distinguished_name(self) -> Optional[pulumi.Input[str]]:
        """
        The distinguished name of the user.
        """
        return pulumi.get(self, "distinguished_name")

    @distinguished_name.setter
    def distinguished_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "distinguished_name", value)

    @property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[str]]:
        """
        A valid email for the user.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email", value)

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the user in an external directory.
        """
        return pulumi.get(self, "external_id")

    @external_id.setter
    def external_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "external_id", value)

    @property
    @pulumi.getter
    def firstname(self) -> Optional[pulumi.Input[str]]:
        """
        The user's first name.
        """
        return pulumi.get(self, "firstname")

    @firstname.setter
    def firstname(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "firstname", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the Group in OneLogin that the user is assigned to.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="invalidLoginAttempts")
    def invalid_login_attempts(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "invalid_login_attempts")

    @invalid_login_attempts.setter
    def invalid_login_attempts(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "invalid_login_attempts", value)

    @property
    @pulumi.getter(name="invitationSentAt")
    def invitation_sent_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "invitation_sent_at")

    @invitation_sent_at.setter
    def invitation_sent_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "invitation_sent_at", value)

    @property
    @pulumi.getter(name="lastLogin")
    def last_login(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "last_login")

    @last_login.setter
    def last_login(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_login", value)

    @property
    @pulumi.getter
    def lastname(self) -> Optional[pulumi.Input[str]]:
        """
        The user's last name.
        """
        return pulumi.get(self, "lastname")

    @lastname.setter
    def lastname(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lastname", value)

    @property
    @pulumi.getter(name="lockedUntil")
    def locked_until(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "locked_until")

    @locked_until.setter
    def locked_until(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "locked_until", value)

    @property
    @pulumi.getter(name="managerAdId")
    def manager_ad_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the user's manager in Active Directory.
        """
        return pulumi.get(self, "manager_ad_id")

    @manager_ad_id.setter
    def manager_ad_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "manager_ad_id", value)

    @property
    @pulumi.getter(name="managerUserId")
    def manager_user_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OneLogin User ID for the user's manager.
        """
        return pulumi.get(self, "manager_user_id")

    @manager_user_id.setter
    def manager_user_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "manager_user_id", value)

    @property
    @pulumi.getter(name="memberOf")
    def member_of(self) -> Optional[pulumi.Input[str]]:
        """
        The user's directory membership.
        """
        return pulumi.get(self, "member_of")

    @member_of.setter
    def member_of(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "member_of", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[str]]:
        """
        The password to set for a user.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="passwordAlgorithm")
    def password_algorithm(self) -> Optional[pulumi.Input[str]]:
        """
        Use this when importing a password that's already hashed. Prepend the salt value to the cleartext password value before
        SHA-256-encoding it
        """
        return pulumi.get(self, "password_algorithm")

    @password_algorithm.setter
    def password_algorithm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password_algorithm", value)

    @property
    @pulumi.getter(name="passwordChangedAt")
    def password_changed_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "password_changed_at")

    @password_changed_at.setter
    def password_changed_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password_changed_at", value)

    @property
    @pulumi.getter(name="passwordConfirmation")
    def password_confirmation(self) -> Optional[pulumi.Input[str]]:
        """
        Required if the password is being set.
        """
        return pulumi.get(self, "password_confirmation")

    @password_confirmation.setter
    def password_confirmation(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "password_confirmation", value)

    @property
    @pulumi.getter
    def phone(self) -> Optional[pulumi.Input[str]]:
        """
        The E.164 format phone number for a user.
        """
        return pulumi.get(self, "phone")

    @phone.setter
    def phone(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "phone", value)

    @property
    @pulumi.getter(name="preferredLocaleCode")
    def preferred_locale_code(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "preferred_locale_code")

    @preferred_locale_code.setter
    def preferred_locale_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "preferred_locale_code", value)

    @property
    @pulumi.getter(name="roleIds")
    def role_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        A list of OneLogin Role IDs of the user
        """
        return pulumi.get(self, "role_ids")

    @role_ids.setter
    def role_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "role_ids", value)

    @property
    @pulumi.getter
    def salt(self) -> Optional[pulumi.Input[str]]:
        """
        The salt value used with the password_algorithm.
        """
        return pulumi.get(self, "salt")

    @salt.setter
    def salt(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "salt", value)

    @property
    @pulumi.getter
    def samaccountname(self) -> Optional[pulumi.Input[str]]:
        """
        The user's Active Directory username.
        """
        return pulumi.get(self, "samaccountname")

    @samaccountname.setter
    def samaccountname(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "samaccountname", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[str]]:
        """
        The user's job title.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "title", value)

    @property
    @pulumi.getter(name="trustedIdpId")
    def trusted_idp_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the OneLogin Trusted IDP of the user.
        """
        return pulumi.get(self, "trusted_idp_id")

    @trusted_idp_id.setter
    def trusted_idp_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "trusted_idp_id", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        A username for the user.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter
    def userprincipalname(self) -> Optional[pulumi.Input[str]]:
        """
        The principle name of the user.
        """
        return pulumi.get(self, "userprincipalname")

    @userprincipalname.setter
    def userprincipalname(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "userprincipalname", value)


class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 activated_at: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 company: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 department: Optional[pulumi.Input[str]] = None,
                 directory_id: Optional[pulumi.Input[int]] = None,
                 distinguished_name: Optional[pulumi.Input[str]] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 firstname: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[int]] = None,
                 invalid_login_attempts: Optional[pulumi.Input[int]] = None,
                 invitation_sent_at: Optional[pulumi.Input[str]] = None,
                 last_login: Optional[pulumi.Input[str]] = None,
                 lastname: Optional[pulumi.Input[str]] = None,
                 locked_until: Optional[pulumi.Input[str]] = None,
                 manager_ad_id: Optional[pulumi.Input[str]] = None,
                 manager_user_id: Optional[pulumi.Input[str]] = None,
                 member_of: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 password_algorithm: Optional[pulumi.Input[str]] = None,
                 password_changed_at: Optional[pulumi.Input[str]] = None,
                 password_confirmation: Optional[pulumi.Input[str]] = None,
                 phone: Optional[pulumi.Input[str]] = None,
                 preferred_locale_code: Optional[pulumi.Input[str]] = None,
                 role_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 salt: Optional[pulumi.Input[str]] = None,
                 samaccountname: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[int]] = None,
                 status: Optional[pulumi.Input[int]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 trusted_idp_id: Optional[pulumi.Input[int]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 userprincipalname: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Create a User resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: Free text related to the user.
        :param pulumi.Input[str] company: The user's company.
        :param pulumi.Input[str] department: The user's department.
        :param pulumi.Input[int] directory_id: The ID of the OneLogin Directory of the user.
        :param pulumi.Input[str] distinguished_name: The distinguished name of the user.
        :param pulumi.Input[str] email: A valid email for the user.
        :param pulumi.Input[str] external_id: The ID of the user in an external directory.
        :param pulumi.Input[str] firstname: The user's first name.
        :param pulumi.Input[int] group_id: The ID of the Group in OneLogin that the user is assigned to.
        :param pulumi.Input[str] lastname: The user's last name.
        :param pulumi.Input[str] manager_ad_id: The ID of the user's manager in Active Directory.
        :param pulumi.Input[str] manager_user_id: The OneLogin User ID for the user's manager.
        :param pulumi.Input[str] member_of: The user's directory membership.
        :param pulumi.Input[str] password: The password to set for a user.
        :param pulumi.Input[str] password_algorithm: Use this when importing a password that's already hashed. Prepend the salt value to the cleartext password value before
               SHA-256-encoding it
        :param pulumi.Input[str] password_confirmation: Required if the password is being set.
        :param pulumi.Input[str] phone: The E.164 format phone number for a user.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] role_ids: A list of OneLogin Role IDs of the user
        :param pulumi.Input[str] salt: The salt value used with the password_algorithm.
        :param pulumi.Input[str] samaccountname: The user's Active Directory username.
        :param pulumi.Input[str] title: The user's job title.
        :param pulumi.Input[int] trusted_idp_id: The ID of the OneLogin Trusted IDP of the user.
        :param pulumi.Input[str] username: A username for the user.
        :param pulumi.Input[str] userprincipalname: The principle name of the user.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[UserArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a User resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 activated_at: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 company: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 department: Optional[pulumi.Input[str]] = None,
                 directory_id: Optional[pulumi.Input[int]] = None,
                 distinguished_name: Optional[pulumi.Input[str]] = None,
                 email: Optional[pulumi.Input[str]] = None,
                 external_id: Optional[pulumi.Input[str]] = None,
                 firstname: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[int]] = None,
                 invalid_login_attempts: Optional[pulumi.Input[int]] = None,
                 invitation_sent_at: Optional[pulumi.Input[str]] = None,
                 last_login: Optional[pulumi.Input[str]] = None,
                 lastname: Optional[pulumi.Input[str]] = None,
                 locked_until: Optional[pulumi.Input[str]] = None,
                 manager_ad_id: Optional[pulumi.Input[str]] = None,
                 manager_user_id: Optional[pulumi.Input[str]] = None,
                 member_of: Optional[pulumi.Input[str]] = None,
                 password: Optional[pulumi.Input[str]] = None,
                 password_algorithm: Optional[pulumi.Input[str]] = None,
                 password_changed_at: Optional[pulumi.Input[str]] = None,
                 password_confirmation: Optional[pulumi.Input[str]] = None,
                 phone: Optional[pulumi.Input[str]] = None,
                 preferred_locale_code: Optional[pulumi.Input[str]] = None,
                 role_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 salt: Optional[pulumi.Input[str]] = None,
                 samaccountname: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[int]] = None,
                 status: Optional[pulumi.Input[int]] = None,
                 title: Optional[pulumi.Input[str]] = None,
                 trusted_idp_id: Optional[pulumi.Input[int]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 userprincipalname: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            __props__.__dict__["activated_at"] = activated_at
            __props__.__dict__["comment"] = comment
            __props__.__dict__["company"] = company
            __props__.__dict__["created_at"] = created_at
            __props__.__dict__["department"] = department
            __props__.__dict__["directory_id"] = directory_id
            __props__.__dict__["distinguished_name"] = distinguished_name
            __props__.__dict__["email"] = email
            __props__.__dict__["external_id"] = external_id
            __props__.__dict__["firstname"] = firstname
            __props__.__dict__["group_id"] = group_id
            __props__.__dict__["invalid_login_attempts"] = invalid_login_attempts
            __props__.__dict__["invitation_sent_at"] = invitation_sent_at
            __props__.__dict__["last_login"] = last_login
            __props__.__dict__["lastname"] = lastname
            __props__.__dict__["locked_until"] = locked_until
            __props__.__dict__["manager_ad_id"] = manager_ad_id
            __props__.__dict__["manager_user_id"] = manager_user_id
            __props__.__dict__["member_of"] = member_of
            __props__.__dict__["password"] = password
            __props__.__dict__["password_algorithm"] = password_algorithm
            __props__.__dict__["password_changed_at"] = password_changed_at
            __props__.__dict__["password_confirmation"] = password_confirmation
            __props__.__dict__["phone"] = phone
            __props__.__dict__["preferred_locale_code"] = preferred_locale_code
            __props__.__dict__["role_ids"] = role_ids
            __props__.__dict__["salt"] = salt
            __props__.__dict__["samaccountname"] = samaccountname
            __props__.__dict__["state"] = state
            __props__.__dict__["status"] = status
            __props__.__dict__["title"] = title
            __props__.__dict__["trusted_idp_id"] = trusted_idp_id
            __props__.__dict__["updated_at"] = updated_at
            __props__.__dict__["username"] = username
            __props__.__dict__["userprincipalname"] = userprincipalname
        super(User, __self__).__init__(
            'onelogin:index/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            activated_at: Optional[pulumi.Input[str]] = None,
            comment: Optional[pulumi.Input[str]] = None,
            company: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            department: Optional[pulumi.Input[str]] = None,
            directory_id: Optional[pulumi.Input[int]] = None,
            distinguished_name: Optional[pulumi.Input[str]] = None,
            email: Optional[pulumi.Input[str]] = None,
            external_id: Optional[pulumi.Input[str]] = None,
            firstname: Optional[pulumi.Input[str]] = None,
            group_id: Optional[pulumi.Input[int]] = None,
            invalid_login_attempts: Optional[pulumi.Input[int]] = None,
            invitation_sent_at: Optional[pulumi.Input[str]] = None,
            last_login: Optional[pulumi.Input[str]] = None,
            lastname: Optional[pulumi.Input[str]] = None,
            locked_until: Optional[pulumi.Input[str]] = None,
            manager_ad_id: Optional[pulumi.Input[str]] = None,
            manager_user_id: Optional[pulumi.Input[str]] = None,
            member_of: Optional[pulumi.Input[str]] = None,
            password: Optional[pulumi.Input[str]] = None,
            password_algorithm: Optional[pulumi.Input[str]] = None,
            password_changed_at: Optional[pulumi.Input[str]] = None,
            password_confirmation: Optional[pulumi.Input[str]] = None,
            phone: Optional[pulumi.Input[str]] = None,
            preferred_locale_code: Optional[pulumi.Input[str]] = None,
            role_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
            salt: Optional[pulumi.Input[str]] = None,
            samaccountname: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[int]] = None,
            status: Optional[pulumi.Input[int]] = None,
            title: Optional[pulumi.Input[str]] = None,
            trusted_idp_id: Optional[pulumi.Input[int]] = None,
            updated_at: Optional[pulumi.Input[str]] = None,
            username: Optional[pulumi.Input[str]] = None,
            userprincipalname: Optional[pulumi.Input[str]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: Free text related to the user.
        :param pulumi.Input[str] company: The user's company.
        :param pulumi.Input[str] department: The user's department.
        :param pulumi.Input[int] directory_id: The ID of the OneLogin Directory of the user.
        :param pulumi.Input[str] distinguished_name: The distinguished name of the user.
        :param pulumi.Input[str] email: A valid email for the user.
        :param pulumi.Input[str] external_id: The ID of the user in an external directory.
        :param pulumi.Input[str] firstname: The user's first name.
        :param pulumi.Input[int] group_id: The ID of the Group in OneLogin that the user is assigned to.
        :param pulumi.Input[str] lastname: The user's last name.
        :param pulumi.Input[str] manager_ad_id: The ID of the user's manager in Active Directory.
        :param pulumi.Input[str] manager_user_id: The OneLogin User ID for the user's manager.
        :param pulumi.Input[str] member_of: The user's directory membership.
        :param pulumi.Input[str] password: The password to set for a user.
        :param pulumi.Input[str] password_algorithm: Use this when importing a password that's already hashed. Prepend the salt value to the cleartext password value before
               SHA-256-encoding it
        :param pulumi.Input[str] password_confirmation: Required if the password is being set.
        :param pulumi.Input[str] phone: The E.164 format phone number for a user.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] role_ids: A list of OneLogin Role IDs of the user
        :param pulumi.Input[str] salt: The salt value used with the password_algorithm.
        :param pulumi.Input[str] samaccountname: The user's Active Directory username.
        :param pulumi.Input[str] title: The user's job title.
        :param pulumi.Input[int] trusted_idp_id: The ID of the OneLogin Trusted IDP of the user.
        :param pulumi.Input[str] username: A username for the user.
        :param pulumi.Input[str] userprincipalname: The principle name of the user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["activated_at"] = activated_at
        __props__.__dict__["comment"] = comment
        __props__.__dict__["company"] = company
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["department"] = department
        __props__.__dict__["directory_id"] = directory_id
        __props__.__dict__["distinguished_name"] = distinguished_name
        __props__.__dict__["email"] = email
        __props__.__dict__["external_id"] = external_id
        __props__.__dict__["firstname"] = firstname
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["invalid_login_attempts"] = invalid_login_attempts
        __props__.__dict__["invitation_sent_at"] = invitation_sent_at
        __props__.__dict__["last_login"] = last_login
        __props__.__dict__["lastname"] = lastname
        __props__.__dict__["locked_until"] = locked_until
        __props__.__dict__["manager_ad_id"] = manager_ad_id
        __props__.__dict__["manager_user_id"] = manager_user_id
        __props__.__dict__["member_of"] = member_of
        __props__.__dict__["password"] = password
        __props__.__dict__["password_algorithm"] = password_algorithm
        __props__.__dict__["password_changed_at"] = password_changed_at
        __props__.__dict__["password_confirmation"] = password_confirmation
        __props__.__dict__["phone"] = phone
        __props__.__dict__["preferred_locale_code"] = preferred_locale_code
        __props__.__dict__["role_ids"] = role_ids
        __props__.__dict__["salt"] = salt
        __props__.__dict__["samaccountname"] = samaccountname
        __props__.__dict__["state"] = state
        __props__.__dict__["status"] = status
        __props__.__dict__["title"] = title
        __props__.__dict__["trusted_idp_id"] = trusted_idp_id
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["username"] = username
        __props__.__dict__["userprincipalname"] = userprincipalname
        return User(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="activatedAt")
    def activated_at(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "activated_at")

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        Free text related to the user.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter
    def company(self) -> pulumi.Output[Optional[str]]:
        """
        The user's company.
        """
        return pulumi.get(self, "company")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def department(self) -> pulumi.Output[Optional[str]]:
        """
        The user's department.
        """
        return pulumi.get(self, "department")

    @property
    @pulumi.getter(name="directoryId")
    def directory_id(self) -> pulumi.Output[Optional[int]]:
        """
        The ID of the OneLogin Directory of the user.
        """
        return pulumi.get(self, "directory_id")

    @property
    @pulumi.getter(name="distinguishedName")
    def distinguished_name(self) -> pulumi.Output[Optional[str]]:
        """
        The distinguished name of the user.
        """
        return pulumi.get(self, "distinguished_name")

    @property
    @pulumi.getter
    def email(self) -> pulumi.Output[Optional[str]]:
        """
        A valid email for the user.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the user in an external directory.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter
    def firstname(self) -> pulumi.Output[Optional[str]]:
        """
        The user's first name.
        """
        return pulumi.get(self, "firstname")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[Optional[int]]:
        """
        The ID of the Group in OneLogin that the user is assigned to.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="invalidLoginAttempts")
    def invalid_login_attempts(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "invalid_login_attempts")

    @property
    @pulumi.getter(name="invitationSentAt")
    def invitation_sent_at(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "invitation_sent_at")

    @property
    @pulumi.getter(name="lastLogin")
    def last_login(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "last_login")

    @property
    @pulumi.getter
    def lastname(self) -> pulumi.Output[Optional[str]]:
        """
        The user's last name.
        """
        return pulumi.get(self, "lastname")

    @property
    @pulumi.getter(name="lockedUntil")
    def locked_until(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "locked_until")

    @property
    @pulumi.getter(name="managerAdId")
    def manager_ad_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the user's manager in Active Directory.
        """
        return pulumi.get(self, "manager_ad_id")

    @property
    @pulumi.getter(name="managerUserId")
    def manager_user_id(self) -> pulumi.Output[Optional[str]]:
        """
        The OneLogin User ID for the user's manager.
        """
        return pulumi.get(self, "manager_user_id")

    @property
    @pulumi.getter(name="memberOf")
    def member_of(self) -> pulumi.Output[Optional[str]]:
        """
        The user's directory membership.
        """
        return pulumi.get(self, "member_of")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[str]]:
        """
        The password to set for a user.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="passwordAlgorithm")
    def password_algorithm(self) -> pulumi.Output[Optional[str]]:
        """
        Use this when importing a password that's already hashed. Prepend the salt value to the cleartext password value before
        SHA-256-encoding it
        """
        return pulumi.get(self, "password_algorithm")

    @property
    @pulumi.getter(name="passwordChangedAt")
    def password_changed_at(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "password_changed_at")

    @property
    @pulumi.getter(name="passwordConfirmation")
    def password_confirmation(self) -> pulumi.Output[Optional[str]]:
        """
        Required if the password is being set.
        """
        return pulumi.get(self, "password_confirmation")

    @property
    @pulumi.getter
    def phone(self) -> pulumi.Output[Optional[str]]:
        """
        The E.164 format phone number for a user.
        """
        return pulumi.get(self, "phone")

    @property
    @pulumi.getter(name="preferredLocaleCode")
    def preferred_locale_code(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "preferred_locale_code")

    @property
    @pulumi.getter(name="roleIds")
    def role_ids(self) -> pulumi.Output[Optional[Sequence[int]]]:
        """
        A list of OneLogin Role IDs of the user
        """
        return pulumi.get(self, "role_ids")

    @property
    @pulumi.getter
    def salt(self) -> pulumi.Output[Optional[str]]:
        """
        The salt value used with the password_algorithm.
        """
        return pulumi.get(self, "salt")

    @property
    @pulumi.getter
    def samaccountname(self) -> pulumi.Output[Optional[str]]:
        """
        The user's Active Directory username.
        """
        return pulumi.get(self, "samaccountname")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def title(self) -> pulumi.Output[Optional[str]]:
        """
        The user's job title.
        """
        return pulumi.get(self, "title")

    @property
    @pulumi.getter(name="trustedIdpId")
    def trusted_idp_id(self) -> pulumi.Output[Optional[int]]:
        """
        The ID of the OneLogin Trusted IDP of the user.
        """
        return pulumi.get(self, "trusted_idp_id")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[Optional[str]]:
        """
        A username for the user.
        """
        return pulumi.get(self, "username")

    @property
    @pulumi.getter
    def userprincipalname(self) -> pulumi.Output[Optional[str]]:
        """
        The principle name of the user.
        """
        return pulumi.get(self, "userprincipalname")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'AppConfiguration',
    'AppEnforcementPoint',
    'AppEnforcementPointResource',
    'AppEnforcementPointSessionExpiryFixed',
    'AppEnforcementPointSessionExpiryInactivity',
    'AppParameters',
    'AppParametersGroups',
    'AppProvisioning',
    'AppSso',
    'AppSsoCertificate',
    'AuthServersConfiguration',
    'PrivilegesPrivilege',
    'PrivilegesPrivilegeStatement',
    'RiskRulesSource',
    'GetAppsConfigurationResult',
    'GetAppsEnforcementPointResult',
    'GetAppsEnforcementPointResourceResult',
    'GetAppsEnforcementPointSessionExpiryFixedResult',
    'GetAppsEnforcementPointSessionExpiryInactivityResult',
    'GetAppsFilterResult',
    'GetAppsParametersResult',
    'GetAppsParametersGroupsResult',
    'GetAppsProvisioningResult',
    'GetAppsSsoResult',
    'GetAppsSsoCertificateResult',
    'GetAuthServersClaimsFilterResult',
    'GetAuthServersConfigurationResult',
    'GetAuthServersFilterResult',
    'GetAuthServersInstanceConfigurationResult',
    'GetAuthServersScopesFilterResult',
    'GetMappingsActionResult',
    'GetMappingsConditionResult',
    'GetMappingsFilterResult',
    'GetPrivilegesFilterResult',
    'GetPrivilegesInstancePrivilegeResult',
    'GetPrivilegesInstancePrivilegeStatementResult',
    'GetPrivilegesPrivilegeResult',
    'GetPrivilegesPrivilegeStatementResult',
    'GetRiskRulesFilterResult',
    'GetRiskRulesInstanceSourceResult',
    'GetRiskRulesSourceResult',
]

@pulumi.output_type
class AppConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "accessTokenExpirationMinutes":
            suggest = "access_token_expiration_minutes"
        elif key == "loginUrl":
            suggest = "login_url"
        elif key == "oidcApiVersion":
            suggest = "oidc_api_version"
        elif key == "oidcApplicationType":
            suggest = "oidc_application_type"
        elif key == "oidcEncryptionKey":
            suggest = "oidc_encryption_key"
        elif key == "postLogoutRedirectUri":
            suggest = "post_logout_redirect_uri"
        elif key == "redirectUri":
            suggest = "redirect_uri"
        elif key == "refreshTokenExpirationMinutes":
            suggest = "refresh_token_expiration_minutes"
        elif key == "tokenEndpointAuthMethod":
            suggest = "token_endpoint_auth_method"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AppConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AppConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AppConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 access_token_expiration_minutes: Optional[int] = None,
                 login_url: Optional[str] = None,
                 oidc_api_version: Optional[str] = None,
                 oidc_application_type: Optional[int] = None,
                 oidc_encryption_key: Optional[str] = None,
                 post_logout_redirect_uri: Optional[str] = None,
                 redirect_uri: Optional[str] = None,
                 refresh_token_expiration_minutes: Optional[int] = None,
                 token_endpoint_auth_method: Optional[int] = None):
        """
        :param int access_token_expiration_minutes: OIDC Apps only Number of minutes the refresh token will be valid for.
        :param str login_url: OIDC Apps only The OpenId Connect Client Id. Note that client_secret is only returned after Creating an App.
        :param int oidc_application_type: OIDC Apps Only
                 - 0: Web
                 - 1: Native/Mobile
        :param str oidc_encryption_key: OIDC Apps only
        :param str post_logout_redirect_uri: OIDC Apps only
        :param str redirect_uri: OIDC Apps only Comma or newline separated list of valid redirect uris for the OpenId Connect Authorization Code flow.
        :param int refresh_token_expiration_minutes: Number of minutes the refresh token will be valid for.
        :param int token_endpoint_auth_method: OIDC Apps only
                - 0: Basic
                - 1: POST
                - 2: None / PKCE
        """
        if access_token_expiration_minutes is not None:
            pulumi.set(__self__, "access_token_expiration_minutes", access_token_expiration_minutes)
        if login_url is not None:
            pulumi.set(__self__, "login_url", login_url)
        if oidc_api_version is not None:
            pulumi.set(__self__, "oidc_api_version", oidc_api_version)
        if oidc_application_type is not None:
            pulumi.set(__self__, "oidc_application_type", oidc_application_type)
        if oidc_encryption_key is not None:
            pulumi.set(__self__, "oidc_encryption_key", oidc_encryption_key)
        if post_logout_redirect_uri is not None:
            pulumi.set(__self__, "post_logout_redirect_uri", post_logout_redirect_uri)
        if redirect_uri is not None:
            pulumi.set(__self__, "redirect_uri", redirect_uri)
        if refresh_token_expiration_minutes is not None:
            pulumi.set(__self__, "refresh_token_expiration_minutes", refresh_token_expiration_minutes)
        if token_endpoint_auth_method is not None:
            pulumi.set(__self__, "token_endpoint_auth_method", token_endpoint_auth_method)

    @property
    @pulumi.getter(name="accessTokenExpirationMinutes")
    def access_token_expiration_minutes(self) -> Optional[int]:
        """
        OIDC Apps only Number of minutes the refresh token will be valid for.
        """
        return pulumi.get(self, "access_token_expiration_minutes")

    @property
    @pulumi.getter(name="loginUrl")
    def login_url(self) -> Optional[str]:
        """
        OIDC Apps only The OpenId Connect Client Id. Note that client_secret is only returned after Creating an App.
        """
        return pulumi.get(self, "login_url")

    @property
    @pulumi.getter(name="oidcApiVersion")
    def oidc_api_version(self) -> Optional[str]:
        return pulumi.get(self, "oidc_api_version")

    @property
    @pulumi.getter(name="oidcApplicationType")
    def oidc_application_type(self) -> Optional[int]:
        """
        OIDC Apps Only
          - 0: Web
          - 1: Native/Mobile
        """
        return pulumi.get(self, "oidc_application_type")

    @property
    @pulumi.getter(name="oidcEncryptionKey")
    def oidc_encryption_key(self) -> Optional[str]:
        """
        OIDC Apps only
        """
        return pulumi.get(self, "oidc_encryption_key")

    @property
    @pulumi.getter(name="postLogoutRedirectUri")
    def post_logout_redirect_uri(self) -> Optional[str]:
        """
        OIDC Apps only
        """
        return pulumi.get(self, "post_logout_redirect_uri")

    @property
    @pulumi.getter(name="redirectUri")
    def redirect_uri(self) -> Optional[str]:
        """
        OIDC Apps only Comma or newline separated list of valid redirect uris for the OpenId Connect Authorization Code flow.
        """
        return pulumi.get(self, "redirect_uri")

    @property
    @pulumi.getter(name="refreshTokenExpirationMinutes")
    def refresh_token_expiration_minutes(self) -> Optional[int]:
        """
        Number of minutes the refresh token will be valid for.
        """
        return pulumi.get(self, "refresh_token_expiration_minutes")

    @property
    @pulumi.getter(name="tokenEndpointAuthMethod")
    def token_endpoint_auth_method(self) -> Optional[int]:
        """
        OIDC Apps only
         - 0: Basic
         - 1: POST
         - 2: None / PKCE
        """
        return pulumi.get(self, "token_endpoint_auth_method")


@pulumi.output_type
class AppEnforcementPoint(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "caseSensitive":
            suggest = "case_sensitive"
        elif key == "contextRoot":
            suggest = "context_root"
        elif key == "landingPage":
            suggest = "landing_page"
        elif key == "requireSitewideAuthentication":
            suggest = "require_sitewide_authentication"
        elif key == "sessionExpiryFixed":
            suggest = "session_expiry_fixed"
        elif key == "sessionExpiryInactivity":
            suggest = "session_expiry_inactivity"
        elif key == "useTargetHostHeader":
            suggest = "use_target_host_header"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AppEnforcementPoint. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AppEnforcementPoint.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AppEnforcementPoint.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 case_sensitive: Optional[bool] = None,
                 conditions: Optional[str] = None,
                 context_root: Optional[str] = None,
                 landing_page: Optional[str] = None,
                 permissions: Optional[str] = None,
                 require_sitewide_authentication: Optional[bool] = None,
                 resources: Optional[Sequence['outputs.AppEnforcementPointResource']] = None,
                 session_expiry_fixed: Optional['outputs.AppEnforcementPointSessionExpiryFixed'] = None,
                 session_expiry_inactivity: Optional['outputs.AppEnforcementPointSessionExpiryInactivity'] = None,
                 target: Optional[str] = None,
                 token: Optional[str] = None,
                 use_target_host_header: Optional[bool] = None,
                 vhost: Optional[str] = None):
        """
        :param bool case_sensitive: The URL path evaluation is case insensitive by default. Resources hosted on web servers such as Apache, NGINX and Java EE are case sensitive paths. Web servers such as Microsoft IIS are not case-sensitive.
        :param str conditions: If access is conditional, the conditions that must evaluate to true to allow access to a resource. For example, to require the user must be authenticated and have either the role Admin or User
        :param str context_root: The root path to the application, often the name of the application. Can be any name, path or just a slash (“/”). The context root uniquely identifies the application within the enforcement point.
        :param str landing_page: The location within the context root to which the browser will be redirected for IdP-initiated single sign-on. For example, the landing page might be an index page in the context root such as index.html or default.aspx. The landing page cannot begin with a slash and must use valid URL characters.
        :param str permissions: Specify to always `allow`, `deny` access to resources, of if access is `conditional`.
        :param bool require_sitewide_authentication: Require user authentication to access any resource protected by this enforcement point.
        :param Sequence['AppEnforcementPointResourceArgs'] resources: Array of resource objects
        :param 'AppEnforcementPointSessionExpiryFixedArgs' session_expiry_fixed: unit: - 0 = Seconds - 1 = Minutes - 2 = Hours value: - When Unit = 0 or 1 value must be 0-60 - When Unit = 2 value must be 0-24
        :param 'AppEnforcementPointSessionExpiryInactivityArgs' session_expiry_inactivity: unit: - 0 = Seconds - 1 = Minutes - 2 = Hours value: - When Unit = 0 or 1 value must be 0-60 - When Unit = 2 value must be 0-24
        :param str target: A fully-qualified URL to the internal application including scheme, authority and path. The target host authority must be an IP address, not a hostname.
        :param str token: Can only be set on create. Access Gateway Token.
        :param bool use_target_host_header: Use the target host header as opposed to the original gateway or upstream host header.
        :param str vhost: A comma-delimited list of one or more virtual hosts that map to applications assigned to the enforcement point. A VHOST may be a host name or an IP address. VHOST distinguish between applications that are at the same context root.
        """
        if case_sensitive is not None:
            pulumi.set(__self__, "case_sensitive", case_sensitive)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if context_root is not None:
            pulumi.set(__self__, "context_root", context_root)
        if landing_page is not None:
            pulumi.set(__self__, "landing_page", landing_page)
        if permissions is not None:
            pulumi.set(__self__, "permissions", permissions)
        if require_sitewide_authentication is not None:
            pulumi.set(__self__, "require_sitewide_authentication", require_sitewide_authentication)
        if resources is not None:
            pulumi.set(__self__, "resources", resources)
        if session_expiry_fixed is not None:
            pulumi.set(__self__, "session_expiry_fixed", session_expiry_fixed)
        if session_expiry_inactivity is not None:
            pulumi.set(__self__, "session_expiry_inactivity", session_expiry_inactivity)
        if target is not None:
            pulumi.set(__self__, "target", target)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if use_target_host_header is not None:
            pulumi.set(__self__, "use_target_host_header", use_target_host_header)
        if vhost is not None:
            pulumi.set(__self__, "vhost", vhost)

    @property
    @pulumi.getter(name="caseSensitive")
    def case_sensitive(self) -> Optional[bool]:
        """
        The URL path evaluation is case insensitive by default. Resources hosted on web servers such as Apache, NGINX and Java EE are case sensitive paths. Web servers such as Microsoft IIS are not case-sensitive.
        """
        return pulumi.get(self, "case_sensitive")

    @property
    @pulumi.getter
    def conditions(self) -> Optional[str]:
        """
        If access is conditional, the conditions that must evaluate to true to allow access to a resource. For example, to require the user must be authenticated and have either the role Admin or User
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter(name="contextRoot")
    def context_root(self) -> Optional[str]:
        """
        The root path to the application, often the name of the application. Can be any name, path or just a slash (“/”). The context root uniquely identifies the application within the enforcement point.
        """
        return pulumi.get(self, "context_root")

    @property
    @pulumi.getter(name="landingPage")
    def landing_page(self) -> Optional[str]:
        """
        The location within the context root to which the browser will be redirected for IdP-initiated single sign-on. For example, the landing page might be an index page in the context root such as index.html or default.aspx. The landing page cannot begin with a slash and must use valid URL characters.
        """
        return pulumi.get(self, "landing_page")

    @property
    @pulumi.getter
    def permissions(self) -> Optional[str]:
        """
        Specify to always `allow`, `deny` access to resources, of if access is `conditional`.
        """
        return pulumi.get(self, "permissions")

    @property
    @pulumi.getter(name="requireSitewideAuthentication")
    def require_sitewide_authentication(self) -> Optional[bool]:
        """
        Require user authentication to access any resource protected by this enforcement point.
        """
        return pulumi.get(self, "require_sitewide_authentication")

    @property
    @pulumi.getter
    def resources(self) -> Optional[Sequence['outputs.AppEnforcementPointResource']]:
        """
        Array of resource objects
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter(name="sessionExpiryFixed")
    def session_expiry_fixed(self) -> Optional['outputs.AppEnforcementPointSessionExpiryFixed']:
        """
        unit: - 0 = Seconds - 1 = Minutes - 2 = Hours value: - When Unit = 0 or 1 value must be 0-60 - When Unit = 2 value must be 0-24
        """
        return pulumi.get(self, "session_expiry_fixed")

    @property
    @pulumi.getter(name="sessionExpiryInactivity")
    def session_expiry_inactivity(self) -> Optional['outputs.AppEnforcementPointSessionExpiryInactivity']:
        """
        unit: - 0 = Seconds - 1 = Minutes - 2 = Hours value: - When Unit = 0 or 1 value must be 0-60 - When Unit = 2 value must be 0-24
        """
        return pulumi.get(self, "session_expiry_inactivity")

    @property
    @pulumi.getter
    def target(self) -> Optional[str]:
        """
        A fully-qualified URL to the internal application including scheme, authority and path. The target host authority must be an IP address, not a hostname.
        """
        return pulumi.get(self, "target")

    @property
    @pulumi.getter
    def token(self) -> Optional[str]:
        """
        Can only be set on create. Access Gateway Token.
        """
        return pulumi.get(self, "token")

    @property
    @pulumi.getter(name="useTargetHostHeader")
    def use_target_host_header(self) -> Optional[bool]:
        """
        Use the target host header as opposed to the original gateway or upstream host header.
        """
        return pulumi.get(self, "use_target_host_header")

    @property
    @pulumi.getter
    def vhost(self) -> Optional[str]:
        """
        A comma-delimited list of one or more virtual hosts that map to applications assigned to the enforcement point. A VHOST may be a host name or an IP address. VHOST distinguish between applications that are at the same context root.
        """
        return pulumi.get(self, "vhost")


@pulumi.output_type
class AppEnforcementPointResource(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "isPathRegex":
            suggest = "is_path_regex"
        elif key == "requireAuth":
            suggest = "require_auth"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AppEnforcementPointResource. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AppEnforcementPointResource.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AppEnforcementPointResource.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 conditions: Optional[str] = None,
                 is_path_regex: Optional[bool] = None,
                 path: Optional[str] = None,
                 permission: Optional[str] = None,
                 require_auth: Optional[bool] = None):
        """
        :param str conditions: required if permission == "conditions"
        """
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if is_path_regex is not None:
            pulumi.set(__self__, "is_path_regex", is_path_regex)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if permission is not None:
            pulumi.set(__self__, "permission", permission)
        if require_auth is not None:
            pulumi.set(__self__, "require_auth", require_auth)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[str]:
        """
        required if permission == "conditions"
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter(name="isPathRegex")
    def is_path_regex(self) -> Optional[bool]:
        return pulumi.get(self, "is_path_regex")

    @property
    @pulumi.getter
    def path(self) -> Optional[str]:
        return pulumi.get(self, "path")

    @property
    @pulumi.getter
    def permission(self) -> Optional[str]:
        return pulumi.get(self, "permission")

    @property
    @pulumi.getter(name="requireAuth")
    def require_auth(self) -> Optional[bool]:
        return pulumi.get(self, "require_auth")


@pulumi.output_type
class AppEnforcementPointSessionExpiryFixed(dict):
    def __init__(__self__, *,
                 unit: Optional[int] = None,
                 value: Optional[int] = None):
        if unit is not None:
            pulumi.set(__self__, "unit", unit)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def unit(self) -> Optional[int]:
        return pulumi.get(self, "unit")

    @property
    @pulumi.getter
    def value(self) -> Optional[int]:
        return pulumi.get(self, "value")


@pulumi.output_type
class AppEnforcementPointSessionExpiryInactivity(dict):
    def __init__(__self__, *,
                 unit: Optional[int] = None,
                 value: Optional[int] = None):
        if unit is not None:
            pulumi.set(__self__, "unit", unit)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def unit(self) -> Optional[int]:
        return pulumi.get(self, "unit")

    @property
    @pulumi.getter
    def value(self) -> Optional[int]:
        return pulumi.get(self, "value")


@pulumi.output_type
class AppParameters(dict):
    def __init__(__self__, *,
                 groups: Optional['outputs.AppParametersGroups'] = None):
        if groups is not None:
            pulumi.set(__self__, "groups", groups)

    @property
    @pulumi.getter
    def groups(self) -> Optional['outputs.AppParametersGroups']:
        return pulumi.get(self, "groups")


@pulumi.output_type
class AppParametersGroups(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "attributesTransformations":
            suggest = "attributes_transformations"
        elif key == "defaultValues":
            suggest = "default_values"
        elif key == "provisionedEntitlements":
            suggest = "provisioned_entitlements"
        elif key == "skipIfBlank":
            suggest = "skip_if_blank"
        elif key == "userAttributeMacros":
            suggest = "user_attribute_macros"
        elif key == "userAttributeMappings":
            suggest = "user_attribute_mappings"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AppParametersGroups. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AppParametersGroups.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AppParametersGroups.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 attributes_transformations: Optional[str] = None,
                 default_values: Optional[str] = None,
                 id: Optional[int] = None,
                 label: Optional[str] = None,
                 provisioned_entitlements: Optional[bool] = None,
                 skip_if_blank: Optional[bool] = None,
                 user_attribute_macros: Optional[str] = None,
                 user_attribute_mappings: Optional[str] = None,
                 values: Optional[str] = None):
        if attributes_transformations is not None:
            pulumi.set(__self__, "attributes_transformations", attributes_transformations)
        if default_values is not None:
            pulumi.set(__self__, "default_values", default_values)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if label is not None:
            pulumi.set(__self__, "label", label)
        if provisioned_entitlements is not None:
            pulumi.set(__self__, "provisioned_entitlements", provisioned_entitlements)
        if skip_if_blank is not None:
            pulumi.set(__self__, "skip_if_blank", skip_if_blank)
        if user_attribute_macros is not None:
            pulumi.set(__self__, "user_attribute_macros", user_attribute_macros)
        if user_attribute_mappings is not None:
            pulumi.set(__self__, "user_attribute_mappings", user_attribute_mappings)
        if values is not None:
            pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter(name="attributesTransformations")
    def attributes_transformations(self) -> Optional[str]:
        return pulumi.get(self, "attributes_transformations")

    @property
    @pulumi.getter(name="defaultValues")
    def default_values(self) -> Optional[str]:
        return pulumi.get(self, "default_values")

    @property
    @pulumi.getter
    def id(self) -> Optional[int]:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def label(self) -> Optional[str]:
        return pulumi.get(self, "label")

    @property
    @pulumi.getter(name="provisionedEntitlements")
    def provisioned_entitlements(self) -> Optional[bool]:
        return pulumi.get(self, "provisioned_entitlements")

    @property
    @pulumi.getter(name="skipIfBlank")
    def skip_if_blank(self) -> Optional[bool]:
        return pulumi.get(self, "skip_if_blank")

    @property
    @pulumi.getter(name="userAttributeMacros")
    def user_attribute_macros(self) -> Optional[str]:
        return pulumi.get(self, "user_attribute_macros")

    @property
    @pulumi.getter(name="userAttributeMappings")
    def user_attribute_mappings(self) -> Optional[str]:
        return pulumi.get(self, "user_attribute_mappings")

    @property
    @pulumi.getter
    def values(self) -> Optional[str]:
        return pulumi.get(self, "values")


@pulumi.output_type
class AppProvisioning(dict):
    def __init__(__self__, *,
                 enabled: Optional[bool] = None,
                 status: Optional[str] = None):
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[bool]:
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")


@pulumi.output_type
class AppSso(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "acsUrl":
            suggest = "acs_url"
        elif key == "clientId":
            suggest = "client_id"
        elif key == "clientSecret":
            suggest = "client_secret"
        elif key == "metadataUrl":
            suggest = "metadata_url"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AppSso. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AppSso.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AppSso.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 acs_url: Optional[str] = None,
                 certificate: Optional['outputs.AppSsoCertificate'] = None,
                 client_id: Optional[str] = None,
                 client_secret: Optional[str] = None,
                 issuer: Optional[str] = None,
                 metadata_url: Optional[str] = None):
        """
        :param str acs_url: App Name.	This is only returned after Creating a SAML App.
        :param 'AppSsoCertificateArgs' certificate: The certificate used for signing.	This is only returned after Creating a SAML App.
        :param str client_id: The OpenId Connect Client Id. Note that client_secret is only returned after Creating an OIDC App.
        :param str client_secret: OpenId Connet Client Secret
        :param str issuer: Issuer of app.	This is only returned after Creating a SAML App.
        :param str metadata_url: ID of the apps underlying connector.	This is only returned after Creating a SAML App.
        """
        if acs_url is not None:
            pulumi.set(__self__, "acs_url", acs_url)
        if certificate is not None:
            pulumi.set(__self__, "certificate", certificate)
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if client_secret is not None:
            pulumi.set(__self__, "client_secret", client_secret)
        if issuer is not None:
            pulumi.set(__self__, "issuer", issuer)
        if metadata_url is not None:
            pulumi.set(__self__, "metadata_url", metadata_url)

    @property
    @pulumi.getter(name="acsUrl")
    def acs_url(self) -> Optional[str]:
        """
        App Name.	This is only returned after Creating a SAML App.
        """
        return pulumi.get(self, "acs_url")

    @property
    @pulumi.getter
    def certificate(self) -> Optional['outputs.AppSsoCertificate']:
        """
        The certificate used for signing.	This is only returned after Creating a SAML App.
        """
        return pulumi.get(self, "certificate")

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[str]:
        """
        The OpenId Connect Client Id. Note that client_secret is only returned after Creating an OIDC App.
        """
        return pulumi.get(self, "client_id")

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> Optional[str]:
        """
        OpenId Connet Client Secret
        """
        return pulumi.get(self, "client_secret")

    @property
    @pulumi.getter
    def issuer(self) -> Optional[str]:
        """
        Issuer of app.	This is only returned after Creating a SAML App.
        """
        return pulumi.get(self, "issuer")

    @property
    @pulumi.getter(name="metadataUrl")
    def metadata_url(self) -> Optional[str]:
        """
        ID of the apps underlying connector.	This is only returned after Creating a SAML App.
        """
        return pulumi.get(self, "metadata_url")


@pulumi.output_type
class AppSsoCertificate(dict):
    def __init__(__self__, *,
                 id: Optional[int] = None,
                 name: Optional[str] = None,
                 value: Optional[str] = None):
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[int]:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def value(self) -> Optional[str]:
        return pulumi.get(self, "value")


@pulumi.output_type
class AuthServersConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "resourceIdentifier":
            suggest = "resource_identifier"
        elif key == "accessTokenExpirationMinutes":
            suggest = "access_token_expiration_minutes"
        elif key == "refreshTokenExpirationMinutes":
            suggest = "refresh_token_expiration_minutes"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AuthServersConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AuthServersConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AuthServersConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 audiences: Sequence[str],
                 resource_identifier: str,
                 access_token_expiration_minutes: Optional[int] = None,
                 refresh_token_expiration_minutes: Optional[int] = None):
        """
        :param Sequence[str] audiences: List of API endpoints that will be returned in Access Tokens.
        :param str resource_identifier: Unique identifier for the API that the Authorization Server will issue Access Tokens for.
        :param int access_token_expiration_minutes: The number of minutes until access token expires. There is no maximum expiry limit.
        :param int refresh_token_expiration_minutes: The number of minutes until refresh token expires. There is no maximum expiry limit.
        """
        pulumi.set(__self__, "audiences", audiences)
        pulumi.set(__self__, "resource_identifier", resource_identifier)
        if access_token_expiration_minutes is not None:
            pulumi.set(__self__, "access_token_expiration_minutes", access_token_expiration_minutes)
        if refresh_token_expiration_minutes is not None:
            pulumi.set(__self__, "refresh_token_expiration_minutes", refresh_token_expiration_minutes)

    @property
    @pulumi.getter
    def audiences(self) -> Sequence[str]:
        """
        List of API endpoints that will be returned in Access Tokens.
        """
        return pulumi.get(self, "audiences")

    @property
    @pulumi.getter(name="resourceIdentifier")
    def resource_identifier(self) -> str:
        """
        Unique identifier for the API that the Authorization Server will issue Access Tokens for.
        """
        return pulumi.get(self, "resource_identifier")

    @property
    @pulumi.getter(name="accessTokenExpirationMinutes")
    def access_token_expiration_minutes(self) -> Optional[int]:
        """
        The number of minutes until access token expires. There is no maximum expiry limit.
        """
        return pulumi.get(self, "access_token_expiration_minutes")

    @property
    @pulumi.getter(name="refreshTokenExpirationMinutes")
    def refresh_token_expiration_minutes(self) -> Optional[int]:
        """
        The number of minutes until refresh token expires. There is no maximum expiry limit.
        """
        return pulumi.get(self, "refresh_token_expiration_minutes")


@pulumi.output_type
class PrivilegesPrivilege(dict):
    def __init__(__self__, *,
                 statements: Optional[Sequence['outputs.PrivilegesPrivilegeStatement']] = None,
                 version: Optional[str] = None):
        if statements is not None:
            pulumi.set(__self__, "statements", statements)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def statements(self) -> Optional[Sequence['outputs.PrivilegesPrivilegeStatement']]:
        return pulumi.get(self, "statements")

    @property
    @pulumi.getter
    def version(self) -> Optional[str]:
        return pulumi.get(self, "version")


@pulumi.output_type
class PrivilegesPrivilegeStatement(dict):
    def __init__(__self__, *,
                 actions: Sequence[str],
                 effect: str,
                 scopes: Sequence[str]):
        """
        :param Sequence[str] actions: An array of strings that represent actions within OneLogin. Actions are prefixed with the class of object they are related to and followed by a specific action for the given class.
               e.g. users:List, where the class is users and the specific action is List. Don’t mix classes within an Action array. To create a privilege that includes multiple different classes, create multiple statements. A wildcard * that includes all actions is supported. Use wildcards to create a Super User privilege.
        :param str effect: Set to “Allow.” By default, all actions are denied, this Statement allows the listed actions to be executed.
        :param Sequence[str] scopes: Target the privileged action against specific resources with the scope.
               The scope pattern is the class of object used by the Action, followed by an ID that represents a resource in OneLogin.
               e.g. apps/1234, where apps is the class and 1234 is the ID of an app.
               The wildcard * is supported and indicates that all resources of the class type declared, in the Action, are in scope.
               The Action and Scope classes must match. However, there is an exception, a scope of roles/{role_id} can be combined with Actions on the user or app class. The exception allows you to target groups of users or apps with specific actions.
        """
        pulumi.set(__self__, "actions", actions)
        pulumi.set(__self__, "effect", effect)
        pulumi.set(__self__, "scopes", scopes)

    @property
    @pulumi.getter
    def actions(self) -> Sequence[str]:
        """
        An array of strings that represent actions within OneLogin. Actions are prefixed with the class of object they are related to and followed by a specific action for the given class.
        e.g. users:List, where the class is users and the specific action is List. Don’t mix classes within an Action array. To create a privilege that includes multiple different classes, create multiple statements. A wildcard * that includes all actions is supported. Use wildcards to create a Super User privilege.
        """
        return pulumi.get(self, "actions")

    @property
    @pulumi.getter
    def effect(self) -> str:
        """
        Set to “Allow.” By default, all actions are denied, this Statement allows the listed actions to be executed.
        """
        return pulumi.get(self, "effect")

    @property
    @pulumi.getter
    def scopes(self) -> Sequence[str]:
        """
        Target the privileged action against specific resources with the scope.
        The scope pattern is the class of object used by the Action, followed by an ID that represents a resource in OneLogin.
        e.g. apps/1234, where apps is the class and 1234 is the ID of an app.
        The wildcard * is supported and indicates that all resources of the class type declared, in the Action, are in scope.
        The Action and Scope classes must match. However, there is an exception, a scope of roles/{role_id} can be combined with Actions on the user or app class. The exception allows you to target groups of users or apps with specific actions.
        """
        return pulumi.get(self, "scopes")


@pulumi.output_type
class RiskRulesSource(dict):
    def __init__(__self__, *,
                 id: Optional[str] = None,
                 name: Optional[str] = None):
        """
        :param str id: A unique id that represents the source of the event.
        :param str name: The name of the source
        """
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        A unique id that represents the source of the event.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The name of the source
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetAppsConfigurationResult(dict):
    def __init__(__self__, *,
                 access_token_expiration_minutes: int,
                 login_url: str,
                 oidc_api_version: str,
                 oidc_application_type: int,
                 oidc_encryption_key: str,
                 post_logout_redirect_uri: str,
                 redirect_uri: str,
                 refresh_token_expiration_minutes: int,
                 token_endpoint_auth_method: int):
        """
        :param int access_token_expiration_minutes: OIDC Apps only Number of minutes the refresh token will be valid for.
        :param str login_url: OIDC Apps only The OpenId Connect Client Id. Note that client_secret is only returned after Creating an App.
        :param int oidc_application_type: OIDC Apps Only
                 - 0: Web
                 - 1: Native/Mobile
        :param str oidc_encryption_key: OIDC Apps only
        :param str post_logout_redirect_uri: OIDC Apps only
        :param str redirect_uri: OIDC Apps only Comma or newline separated list of valid redirect uris for the OpenId Connect Authorization Code flow.
        :param int refresh_token_expiration_minutes: Number of minutes the refresh token will be valid for.
        :param int token_endpoint_auth_method: OIDC Apps only
                - 0: Basic
                - 1: POST
                - 2: None / PKCE
        """
        pulumi.set(__self__, "access_token_expiration_minutes", access_token_expiration_minutes)
        pulumi.set(__self__, "login_url", login_url)
        pulumi.set(__self__, "oidc_api_version", oidc_api_version)
        pulumi.set(__self__, "oidc_application_type", oidc_application_type)
        pulumi.set(__self__, "oidc_encryption_key", oidc_encryption_key)
        pulumi.set(__self__, "post_logout_redirect_uri", post_logout_redirect_uri)
        pulumi.set(__self__, "redirect_uri", redirect_uri)
        pulumi.set(__self__, "refresh_token_expiration_minutes", refresh_token_expiration_minutes)
        pulumi.set(__self__, "token_endpoint_auth_method", token_endpoint_auth_method)

    @property
    @pulumi.getter(name="accessTokenExpirationMinutes")
    def access_token_expiration_minutes(self) -> int:
        """
        OIDC Apps only Number of minutes the refresh token will be valid for.
        """
        return pulumi.get(self, "access_token_expiration_minutes")

    @property
    @pulumi.getter(name="loginUrl")
    def login_url(self) -> str:
        """
        OIDC Apps only The OpenId Connect Client Id. Note that client_secret is only returned after Creating an App.
        """
        return pulumi.get(self, "login_url")

    @property
    @pulumi.getter(name="oidcApiVersion")
    def oidc_api_version(self) -> str:
        return pulumi.get(self, "oidc_api_version")

    @property
    @pulumi.getter(name="oidcApplicationType")
    def oidc_application_type(self) -> int:
        """
        OIDC Apps Only
          - 0: Web
          - 1: Native/Mobile
        """
        return pulumi.get(self, "oidc_application_type")

    @property
    @pulumi.getter(name="oidcEncryptionKey")
    def oidc_encryption_key(self) -> str:
        """
        OIDC Apps only
        """
        return pulumi.get(self, "oidc_encryption_key")

    @property
    @pulumi.getter(name="postLogoutRedirectUri")
    def post_logout_redirect_uri(self) -> str:
        """
        OIDC Apps only
        """
        return pulumi.get(self, "post_logout_redirect_uri")

    @property
    @pulumi.getter(name="redirectUri")
    def redirect_uri(self) -> str:
        """
        OIDC Apps only Comma or newline separated list of valid redirect uris for the OpenId Connect Authorization Code flow.
        """
        return pulumi.get(self, "redirect_uri")

    @property
    @pulumi.getter(name="refreshTokenExpirationMinutes")
    def refresh_token_expiration_minutes(self) -> int:
        """
        Number of minutes the refresh token will be valid for.
        """
        return pulumi.get(self, "refresh_token_expiration_minutes")

    @property
    @pulumi.getter(name="tokenEndpointAuthMethod")
    def token_endpoint_auth_method(self) -> int:
        """
        OIDC Apps only
         - 0: Basic
         - 1: POST
         - 2: None / PKCE
        """
        return pulumi.get(self, "token_endpoint_auth_method")


@pulumi.output_type
class GetAppsEnforcementPointResult(dict):
    def __init__(__self__, *,
                 case_sensitive: bool,
                 conditions: str,
                 context_root: str,
                 landing_page: str,
                 permissions: str,
                 require_sitewide_authentication: bool,
                 resources: Sequence['outputs.GetAppsEnforcementPointResourceResult'],
                 session_expiry_fixed: 'outputs.GetAppsEnforcementPointSessionExpiryFixedResult',
                 session_expiry_inactivity: 'outputs.GetAppsEnforcementPointSessionExpiryInactivityResult',
                 target: str,
                 token: str,
                 use_target_host_header: bool,
                 vhost: str):
        """
        :param bool case_sensitive: The URL path evaluation is case insensitive by default. Resources hosted on web servers such as Apache, NGINX and Java EE are case sensitive paths. Web servers such as Microsoft IIS are not case-sensitive.
        :param str conditions: If access is conditional, the conditions that must evaluate to true to allow access to a resource. For example, to require the user must be authenticated and have either the role Admin or User
        :param str context_root: The root path to the application, often the name of the application. Can be any name, path or just a slash (“/”). The context root uniquely identifies the application within the enforcement point.
        :param str landing_page: The location within the context root to which the browser will be redirected for IdP-initiated single sign-on. For example, the landing page might be an index page in the context root such as index.html or default.aspx. The landing page cannot begin with a slash and must use valid URL characters.
        :param str permissions: Specify to always `allow`, `deny` access to resources, of if access is `conditional`.
        :param bool require_sitewide_authentication: Require user authentication to access any resource protected by this enforcement point.
        :param Sequence['GetAppsEnforcementPointResourceArgs'] resources: Array of resource objects
        :param 'GetAppsEnforcementPointSessionExpiryFixedArgs' session_expiry_fixed: unit: - 0 = Seconds - 1 = Minutes - 2 = Hours value: - When Unit = 0 or 1 value must be 0-60 - When Unit = 2 value must be 0-24
        :param 'GetAppsEnforcementPointSessionExpiryInactivityArgs' session_expiry_inactivity: unit: - 0 = Seconds - 1 = Minutes - 2 = Hours value: - When Unit = 0 or 1 value must be 0-60 - When Unit = 2 value must be 0-24
        :param str target: A fully-qualified URL to the internal application including scheme, authority and path. The target host authority must be an IP address, not a hostname.
        :param str token: Can only be set on create. Access Gateway Token.
        :param bool use_target_host_header: Use the target host header as opposed to the original gateway or upstream host header.
        :param str vhost: A comma-delimited list of one or more virtual hosts that map to applications assigned to the enforcement point. A VHOST may be a host name or an IP address. VHOST distinguish between applications that are at the same context root.
        """
        pulumi.set(__self__, "case_sensitive", case_sensitive)
        pulumi.set(__self__, "conditions", conditions)
        pulumi.set(__self__, "context_root", context_root)
        pulumi.set(__self__, "landing_page", landing_page)
        pulumi.set(__self__, "permissions", permissions)
        pulumi.set(__self__, "require_sitewide_authentication", require_sitewide_authentication)
        pulumi.set(__self__, "resources", resources)
        pulumi.set(__self__, "session_expiry_fixed", session_expiry_fixed)
        pulumi.set(__self__, "session_expiry_inactivity", session_expiry_inactivity)
        pulumi.set(__self__, "target", target)
        pulumi.set(__self__, "token", token)
        pulumi.set(__self__, "use_target_host_header", use_target_host_header)
        pulumi.set(__self__, "vhost", vhost)

    @property
    @pulumi.getter(name="caseSensitive")
    def case_sensitive(self) -> bool:
        """
        The URL path evaluation is case insensitive by default. Resources hosted on web servers such as Apache, NGINX and Java EE are case sensitive paths. Web servers such as Microsoft IIS are not case-sensitive.
        """
        return pulumi.get(self, "case_sensitive")

    @property
    @pulumi.getter
    def conditions(self) -> str:
        """
        If access is conditional, the conditions that must evaluate to true to allow access to a resource. For example, to require the user must be authenticated and have either the role Admin or User
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter(name="contextRoot")
    def context_root(self) -> str:
        """
        The root path to the application, often the name of the application. Can be any name, path or just a slash (“/”). The context root uniquely identifies the application within the enforcement point.
        """
        return pulumi.get(self, "context_root")

    @property
    @pulumi.getter(name="landingPage")
    def landing_page(self) -> str:
        """
        The location within the context root to which the browser will be redirected for IdP-initiated single sign-on. For example, the landing page might be an index page in the context root such as index.html or default.aspx. The landing page cannot begin with a slash and must use valid URL characters.
        """
        return pulumi.get(self, "landing_page")

    @property
    @pulumi.getter
    def permissions(self) -> str:
        """
        Specify to always `allow`, `deny` access to resources, of if access is `conditional`.
        """
        return pulumi.get(self, "permissions")

    @property
    @pulumi.getter(name="requireSitewideAuthentication")
    def require_sitewide_authentication(self) -> bool:
        """
        Require user authentication to access any resource protected by this enforcement point.
        """
        return pulumi.get(self, "require_sitewide_authentication")

    @property
    @pulumi.getter
    def resources(self) -> Sequence['outputs.GetAppsEnforcementPointResourceResult']:
        """
        Array of resource objects
        """
        return pulumi.get(self, "resources")

    @property
    @pulumi.getter(name="sessionExpiryFixed")
    def session_expiry_fixed(self) -> 'outputs.GetAppsEnforcementPointSessionExpiryFixedResult':
        """
        unit: - 0 = Seconds - 1 = Minutes - 2 = Hours value: - When Unit = 0 or 1 value must be 0-60 - When Unit = 2 value must be 0-24
        """
        return pulumi.get(self, "session_expiry_fixed")

    @property
    @pulumi.getter(name="sessionExpiryInactivity")
    def session_expiry_inactivity(self) -> 'outputs.GetAppsEnforcementPointSessionExpiryInactivityResult':
        """
        unit: - 0 = Seconds - 1 = Minutes - 2 = Hours value: - When Unit = 0 or 1 value must be 0-60 - When Unit = 2 value must be 0-24
        """
        return pulumi.get(self, "session_expiry_inactivity")

    @property
    @pulumi.getter
    def target(self) -> str:
        """
        A fully-qualified URL to the internal application including scheme, authority and path. The target host authority must be an IP address, not a hostname.
        """
        return pulumi.get(self, "target")

    @property
    @pulumi.getter
    def token(self) -> str:
        """
        Can only be set on create. Access Gateway Token.
        """
        return pulumi.get(self, "token")

    @property
    @pulumi.getter(name="useTargetHostHeader")
    def use_target_host_header(self) -> bool:
        """
        Use the target host header as opposed to the original gateway or upstream host header.
        """
        return pulumi.get(self, "use_target_host_header")

    @property
    @pulumi.getter
    def vhost(self) -> str:
        """
        A comma-delimited list of one or more virtual hosts that map to applications assigned to the enforcement point. A VHOST may be a host name or an IP address. VHOST distinguish between applications that are at the same context root.
        """
        return pulumi.get(self, "vhost")


@pulumi.output_type
class GetAppsEnforcementPointResourceResult(dict):
    def __init__(__self__, *,
                 conditions: str,
                 is_path_regex: bool,
                 path: str,
                 permission: str,
                 require_auth: bool):
        """
        :param str conditions: required if permission == "conditions"
        """
        pulumi.set(__self__, "conditions", conditions)
        pulumi.set(__self__, "is_path_regex", is_path_regex)
        pulumi.set(__self__, "path", path)
        pulumi.set(__self__, "permission", permission)
        pulumi.set(__self__, "require_auth", require_auth)

    @property
    @pulumi.getter
    def conditions(self) -> str:
        """
        required if permission == "conditions"
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter(name="isPathRegex")
    def is_path_regex(self) -> bool:
        return pulumi.get(self, "is_path_regex")

    @property
    @pulumi.getter
    def path(self) -> str:
        return pulumi.get(self, "path")

    @property
    @pulumi.getter
    def permission(self) -> str:
        return pulumi.get(self, "permission")

    @property
    @pulumi.getter(name="requireAuth")
    def require_auth(self) -> bool:
        return pulumi.get(self, "require_auth")


@pulumi.output_type
class GetAppsEnforcementPointSessionExpiryFixedResult(dict):
    def __init__(__self__, *,
                 unit: int,
                 value: int):
        pulumi.set(__self__, "unit", unit)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def unit(self) -> int:
        return pulumi.get(self, "unit")

    @property
    @pulumi.getter
    def value(self) -> int:
        return pulumi.get(self, "value")


@pulumi.output_type
class GetAppsEnforcementPointSessionExpiryInactivityResult(dict):
    def __init__(__self__, *,
                 unit: int,
                 value: int):
        pulumi.set(__self__, "unit", unit)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def unit(self) -> int:
        return pulumi.get(self, "unit")

    @property
    @pulumi.getter
    def value(self) -> int:
        return pulumi.get(self, "value")


@pulumi.output_type
class GetAppsFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str]):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")


@pulumi.output_type
class GetAppsParametersResult(dict):
    def __init__(__self__, *,
                 groups: 'outputs.GetAppsParametersGroupsResult'):
        pulumi.set(__self__, "groups", groups)

    @property
    @pulumi.getter
    def groups(self) -> 'outputs.GetAppsParametersGroupsResult':
        return pulumi.get(self, "groups")


@pulumi.output_type
class GetAppsParametersGroupsResult(dict):
    def __init__(__self__, *,
                 attributes_transformations: str,
                 default_values: str,
                 id: int,
                 label: str,
                 provisioned_entitlements: bool,
                 skip_if_blank: bool,
                 user_attribute_macros: str,
                 user_attribute_mappings: str,
                 values: str):
        pulumi.set(__self__, "attributes_transformations", attributes_transformations)
        pulumi.set(__self__, "default_values", default_values)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "provisioned_entitlements", provisioned_entitlements)
        pulumi.set(__self__, "skip_if_blank", skip_if_blank)
        pulumi.set(__self__, "user_attribute_macros", user_attribute_macros)
        pulumi.set(__self__, "user_attribute_mappings", user_attribute_mappings)
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter(name="attributesTransformations")
    def attributes_transformations(self) -> str:
        return pulumi.get(self, "attributes_transformations")

    @property
    @pulumi.getter(name="defaultValues")
    def default_values(self) -> str:
        return pulumi.get(self, "default_values")

    @property
    @pulumi.getter
    def id(self) -> int:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def label(self) -> str:
        return pulumi.get(self, "label")

    @property
    @pulumi.getter(name="provisionedEntitlements")
    def provisioned_entitlements(self) -> bool:
        return pulumi.get(self, "provisioned_entitlements")

    @property
    @pulumi.getter(name="skipIfBlank")
    def skip_if_blank(self) -> bool:
        return pulumi.get(self, "skip_if_blank")

    @property
    @pulumi.getter(name="userAttributeMacros")
    def user_attribute_macros(self) -> str:
        return pulumi.get(self, "user_attribute_macros")

    @property
    @pulumi.getter(name="userAttributeMappings")
    def user_attribute_mappings(self) -> str:
        return pulumi.get(self, "user_attribute_mappings")

    @property
    @pulumi.getter
    def values(self) -> str:
        return pulumi.get(self, "values")


@pulumi.output_type
class GetAppsProvisioningResult(dict):
    def __init__(__self__, *,
                 enabled: bool,
                 status: str):
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def enabled(self) -> bool:
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def status(self) -> str:
        return pulumi.get(self, "status")


@pulumi.output_type
class GetAppsSsoResult(dict):
    def __init__(__self__, *,
                 acs_url: str,
                 certificate: 'outputs.GetAppsSsoCertificateResult',
                 client_id: str,
                 client_secret: str,
                 issuer: str,
                 metadata_url: str):
        """
        :param str acs_url: App Name.	This is only returned after Creating a SAML App.
        :param 'GetAppsSsoCertificateArgs' certificate: The certificate used for signing.	This is only returned after Creating a SAML App.
        :param str client_id: The OpenId Connect Client Id. Note that client_secret is only returned after Creating an OIDC App.
        :param str client_secret: OpenId Connet Client Secret
        :param str issuer: Issuer of app.	This is only returned after Creating a SAML App.
        :param str metadata_url: ID of the apps underlying connector.	This is only returned after Creating a SAML App.
        """
        pulumi.set(__self__, "acs_url", acs_url)
        pulumi.set(__self__, "certificate", certificate)
        pulumi.set(__self__, "client_id", client_id)
        pulumi.set(__self__, "client_secret", client_secret)
        pulumi.set(__self__, "issuer", issuer)
        pulumi.set(__self__, "metadata_url", metadata_url)

    @property
    @pulumi.getter(name="acsUrl")
    def acs_url(self) -> str:
        """
        App Name.	This is only returned after Creating a SAML App.
        """
        return pulumi.get(self, "acs_url")

    @property
    @pulumi.getter
    def certificate(self) -> 'outputs.GetAppsSsoCertificateResult':
        """
        The certificate used for signing.	This is only returned after Creating a SAML App.
        """
        return pulumi.get(self, "certificate")

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> str:
        """
        The OpenId Connect Client Id. Note that client_secret is only returned after Creating an OIDC App.
        """
        return pulumi.get(self, "client_id")

    @property
    @pulumi.getter(name="clientSecret")
    def client_secret(self) -> str:
        """
        OpenId Connet Client Secret
        """
        return pulumi.get(self, "client_secret")

    @property
    @pulumi.getter
    def issuer(self) -> str:
        """
        Issuer of app.	This is only returned after Creating a SAML App.
        """
        return pulumi.get(self, "issuer")

    @property
    @pulumi.getter(name="metadataUrl")
    def metadata_url(self) -> str:
        """
        ID of the apps underlying connector.	This is only returned after Creating a SAML App.
        """
        return pulumi.get(self, "metadata_url")


@pulumi.output_type
class GetAppsSsoCertificateResult(dict):
    def __init__(__self__, *,
                 id: int,
                 name: str,
                 value: str):
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def id(self) -> int:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


@pulumi.output_type
class GetAuthServersClaimsFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str]):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")


@pulumi.output_type
class GetAuthServersConfigurationResult(dict):
    def __init__(__self__, *,
                 access_token_expiration_minutes: int,
                 audiences: Sequence[str],
                 refresh_token_expiration_minutes: int,
                 resource_identifier: str):
        """
        :param int access_token_expiration_minutes: The number of minutes until access token expires. There is no maximum expiry limit.
        :param Sequence[str] audiences: List of API endpoints that will be returned in Access Tokens.
        :param int refresh_token_expiration_minutes: The number of minutes until refresh token expires. There is no maximum expiry limit.
        :param str resource_identifier: Unique identifier for the API that the Authorization Server will issue Access Tokens for.
        """
        pulumi.set(__self__, "access_token_expiration_minutes", access_token_expiration_minutes)
        pulumi.set(__self__, "audiences", audiences)
        pulumi.set(__self__, "refresh_token_expiration_minutes", refresh_token_expiration_minutes)
        pulumi.set(__self__, "resource_identifier", resource_identifier)

    @property
    @pulumi.getter(name="accessTokenExpirationMinutes")
    def access_token_expiration_minutes(self) -> int:
        """
        The number of minutes until access token expires. There is no maximum expiry limit.
        """
        return pulumi.get(self, "access_token_expiration_minutes")

    @property
    @pulumi.getter
    def audiences(self) -> Sequence[str]:
        """
        List of API endpoints that will be returned in Access Tokens.
        """
        return pulumi.get(self, "audiences")

    @property
    @pulumi.getter(name="refreshTokenExpirationMinutes")
    def refresh_token_expiration_minutes(self) -> int:
        """
        The number of minutes until refresh token expires. There is no maximum expiry limit.
        """
        return pulumi.get(self, "refresh_token_expiration_minutes")

    @property
    @pulumi.getter(name="resourceIdentifier")
    def resource_identifier(self) -> str:
        """
        Unique identifier for the API that the Authorization Server will issue Access Tokens for.
        """
        return pulumi.get(self, "resource_identifier")


@pulumi.output_type
class GetAuthServersFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str]):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")


@pulumi.output_type
class GetAuthServersInstanceConfigurationResult(dict):
    def __init__(__self__, *,
                 access_token_expiration_minutes: int,
                 audiences: Sequence[str],
                 refresh_token_expiration_minutes: int,
                 resource_identifier: str):
        """
        :param int access_token_expiration_minutes: The number of minutes until access token expires. There is no maximum expiry limit.
        :param Sequence[str] audiences: List of API endpoints that will be returned in Access Tokens.
        :param int refresh_token_expiration_minutes: The number of minutes until refresh token expires. There is no maximum expiry limit.
        :param str resource_identifier: Unique identifier for the API that the Authorization Server will issue Access Tokens for.
        """
        pulumi.set(__self__, "access_token_expiration_minutes", access_token_expiration_minutes)
        pulumi.set(__self__, "audiences", audiences)
        pulumi.set(__self__, "refresh_token_expiration_minutes", refresh_token_expiration_minutes)
        pulumi.set(__self__, "resource_identifier", resource_identifier)

    @property
    @pulumi.getter(name="accessTokenExpirationMinutes")
    def access_token_expiration_minutes(self) -> int:
        """
        The number of minutes until access token expires. There is no maximum expiry limit.
        """
        return pulumi.get(self, "access_token_expiration_minutes")

    @property
    @pulumi.getter
    def audiences(self) -> Sequence[str]:
        """
        List of API endpoints that will be returned in Access Tokens.
        """
        return pulumi.get(self, "audiences")

    @property
    @pulumi.getter(name="refreshTokenExpirationMinutes")
    def refresh_token_expiration_minutes(self) -> int:
        """
        The number of minutes until refresh token expires. There is no maximum expiry limit.
        """
        return pulumi.get(self, "refresh_token_expiration_minutes")

    @property
    @pulumi.getter(name="resourceIdentifier")
    def resource_identifier(self) -> str:
        """
        Unique identifier for the API that the Authorization Server will issue Access Tokens for.
        """
        return pulumi.get(self, "resource_identifier")


@pulumi.output_type
class GetAuthServersScopesFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str]):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")


@pulumi.output_type
class GetMappingsActionResult(dict):
    def __init__(__self__, *,
                 action: str,
                 values: Sequence[str]):
        """
        :param str action: The action to apply
        :param Sequence[str] values: Only applicable to provisioned and set_* actions. Items in the array will be a plain text string or valid value for the selected action.
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def action(self) -> str:
        """
        The action to apply
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        """
        Only applicable to provisioned and set_* actions. Items in the array will be a plain text string or valid value for the selected action.
        """
        return pulumi.get(self, "values")


@pulumi.output_type
class GetMappingsConditionResult(dict):
    def __init__(__self__, *,
                 operator: str,
                 source: str,
                 value: str):
        """
        :param str operator: A valid operator for the selected condition source
        :param str source: source field to check.
        :param str value: A plain text string or valid value for the selected  condition source
        """
        pulumi.set(__self__, "operator", operator)
        pulumi.set(__self__, "source", source)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def operator(self) -> str:
        """
        A valid operator for the selected condition source
        """
        return pulumi.get(self, "operator")

    @property
    @pulumi.getter
    def source(self) -> str:
        """
        source field to check.
        """
        return pulumi.get(self, "source")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        A plain text string or valid value for the selected  condition source
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetMappingsFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str]):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")


@pulumi.output_type
class GetPrivilegesFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str]):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")


@pulumi.output_type
class GetPrivilegesInstancePrivilegeResult(dict):
    def __init__(__self__, *,
                 statements: Sequence['outputs.GetPrivilegesInstancePrivilegeStatementResult'],
                 version: str):
        pulumi.set(__self__, "statements", statements)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def statements(self) -> Sequence['outputs.GetPrivilegesInstancePrivilegeStatementResult']:
        return pulumi.get(self, "statements")

    @property
    @pulumi.getter
    def version(self) -> str:
        return pulumi.get(self, "version")


@pulumi.output_type
class GetPrivilegesInstancePrivilegeStatementResult(dict):
    def __init__(__self__, *,
                 actions: Sequence[str],
                 effect: str,
                 scopes: Sequence[str]):
        """
        :param Sequence[str] actions: An array of strings that represent actions within OneLogin. Actions are prefixed with the class of object they are related to and followed by a specific action for the given class.
               e.g. users:List, where the class is users and the specific action is List. Don’t mix classes within an Action array. To create a privilege that includes multiple different classes, create multiple statements. A wildcard * that includes all actions is supported. Use wildcards to create a Super User privilege.
        :param str effect: Set to “Allow.” By default, all actions are denied, this Statement allows the listed actions to be executed.
        :param Sequence[str] scopes: Target the privileged action against specific resources with the scope.
               The scope pattern is the class of object used by the Action, followed by an ID that represents a resource in OneLogin.
               e.g. apps/1234, where apps is the class and 1234 is the ID of an app.
               The wildcard * is supported and indicates that all resources of the class type declared, in the Action, are in scope.
               The Action and Scope classes must match. However, there is an exception, a scope of roles/{role_id} can be combined with Actions on the user or app class. The exception allows you to target groups of users or apps with specific actions.
        """
        pulumi.set(__self__, "actions", actions)
        pulumi.set(__self__, "effect", effect)
        pulumi.set(__self__, "scopes", scopes)

    @property
    @pulumi.getter
    def actions(self) -> Sequence[str]:
        """
        An array of strings that represent actions within OneLogin. Actions are prefixed with the class of object they are related to and followed by a specific action for the given class.
        e.g. users:List, where the class is users and the specific action is List. Don’t mix classes within an Action array. To create a privilege that includes multiple different classes, create multiple statements. A wildcard * that includes all actions is supported. Use wildcards to create a Super User privilege.
        """
        return pulumi.get(self, "actions")

    @property
    @pulumi.getter
    def effect(self) -> str:
        """
        Set to “Allow.” By default, all actions are denied, this Statement allows the listed actions to be executed.
        """
        return pulumi.get(self, "effect")

    @property
    @pulumi.getter
    def scopes(self) -> Sequence[str]:
        """
        Target the privileged action against specific resources with the scope.
        The scope pattern is the class of object used by the Action, followed by an ID that represents a resource in OneLogin.
        e.g. apps/1234, where apps is the class and 1234 is the ID of an app.
        The wildcard * is supported and indicates that all resources of the class type declared, in the Action, are in scope.
        The Action and Scope classes must match. However, there is an exception, a scope of roles/{role_id} can be combined with Actions on the user or app class. The exception allows you to target groups of users or apps with specific actions.
        """
        return pulumi.get(self, "scopes")


@pulumi.output_type
class GetPrivilegesPrivilegeResult(dict):
    def __init__(__self__, *,
                 statements: Sequence['outputs.GetPrivilegesPrivilegeStatementResult'],
                 version: str):
        pulumi.set(__self__, "statements", statements)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def statements(self) -> Sequence['outputs.GetPrivilegesPrivilegeStatementResult']:
        return pulumi.get(self, "statements")

    @property
    @pulumi.getter
    def version(self) -> str:
        return pulumi.get(self, "version")


@pulumi.output_type
class GetPrivilegesPrivilegeStatementResult(dict):
    def __init__(__self__, *,
                 actions: Sequence[str],
                 effect: str,
                 scopes: Sequence[str]):
        """
        :param Sequence[str] actions: An array of strings that represent actions within OneLogin. Actions are prefixed with the class of object they are related to and followed by a specific action for the given class.
               e.g. users:List, where the class is users and the specific action is List. Don’t mix classes within an Action array. To create a privilege that includes multiple different classes, create multiple statements. A wildcard * that includes all actions is supported. Use wildcards to create a Super User privilege.
        :param str effect: Set to “Allow.” By default, all actions are denied, this Statement allows the listed actions to be executed.
        :param Sequence[str] scopes: Target the privileged action against specific resources with the scope.
               The scope pattern is the class of object used by the Action, followed by an ID that represents a resource in OneLogin.
               e.g. apps/1234, where apps is the class and 1234 is the ID of an app.
               The wildcard * is supported and indicates that all resources of the class type declared, in the Action, are in scope.
               The Action and Scope classes must match. However, there is an exception, a scope of roles/{role_id} can be combined with Actions on the user or app class. The exception allows you to target groups of users or apps with specific actions.
        """
        pulumi.set(__self__, "actions", actions)
        pulumi.set(__self__, "effect", effect)
        pulumi.set(__self__, "scopes", scopes)

    @property
    @pulumi.getter
    def actions(self) -> Sequence[str]:
        """
        An array of strings that represent actions within OneLogin. Actions are prefixed with the class of object they are related to and followed by a specific action for the given class.
        e.g. users:List, where the class is users and the specific action is List. Don’t mix classes within an Action array. To create a privilege that includes multiple different classes, create multiple statements. A wildcard * that includes all actions is supported. Use wildcards to create a Super User privilege.
        """
        return pulumi.get(self, "actions")

    @property
    @pulumi.getter
    def effect(self) -> str:
        """
        Set to “Allow.” By default, all actions are denied, this Statement allows the listed actions to be executed.
        """
        return pulumi.get(self, "effect")

    @property
    @pulumi.getter
    def scopes(self) -> Sequence[str]:
        """
        Target the privileged action against specific resources with the scope.
        The scope pattern is the class of object used by the Action, followed by an ID that represents a resource in OneLogin.
        e.g. apps/1234, where apps is the class and 1234 is the ID of an app.
        The wildcard * is supported and indicates that all resources of the class type declared, in the Action, are in scope.
        The Action and Scope classes must match. However, there is an exception, a scope of roles/{role_id} can be combined with Actions on the user or app class. The exception allows you to target groups of users or apps with specific actions.
        """
        return pulumi.get(self, "scopes")


@pulumi.output_type
class GetRiskRulesFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str]):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")


@pulumi.output_type
class GetRiskRulesInstanceSourceResult(dict):
    def __init__(__self__, *,
                 id: str,
                 name: str):
        """
        :param str id: A unique id that represents the source of the event.
        :param str name: The name of the source
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        A unique id that represents the source of the event.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the source
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetRiskRulesSourceResult(dict):
    def __init__(__self__, *,
                 id: str,
                 name: str):
        """
        :param str id: A unique id that represents the source of the event.
        :param str name: The name of the source
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        A unique id that represents the source of the event.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the source
        """
        return pulumi.get(self, "name")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PrivilegesArgs', 'Privileges']

@pulumi.input_type
class PrivilegesArgs:
    def __init__(__self__, *,
                 privilege: pulumi.Input['PrivilegesPrivilegeArgs'],
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Privileges resource.
        """
        pulumi.set(__self__, "privilege", privilege)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def privilege(self) -> pulumi.Input['PrivilegesPrivilegeArgs']:
        return pulumi.get(self, "privilege")

    @privilege.setter
    def privilege(self, value: pulumi.Input['PrivilegesPrivilegeArgs']):
        pulumi.set(self, "privilege", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _PrivilegesState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 privilege: Optional[pulumi.Input['PrivilegesPrivilegeArgs']] = None):
        """
        Input properties used for looking up and filtering Privileges resources.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if privilege is not None:
            pulumi.set(__self__, "privilege", privilege)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def privilege(self) -> Optional[pulumi.Input['PrivilegesPrivilegeArgs']]:
        return pulumi.get(self, "privilege")

    @privilege.setter
    def privilege(self, value: Optional[pulumi.Input['PrivilegesPrivilegeArgs']]):
        pulumi.set(self, "privilege", value)


class Privileges(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 privilege: Optional[pulumi.Input[pulumi.InputType['PrivilegesPrivilegeArgs']]] = None,
                 __props__=None):
        """
        Create a Privileges resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PrivilegesArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Privileges resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param PrivilegesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PrivilegesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 privilege: Optional[pulumi.Input[pulumi.InputType['PrivilegesPrivilegeArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PrivilegesArgs.__new__(PrivilegesArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if privilege is None and not opts.urn:
                raise TypeError("Missing required property 'privilege'")
            __props__.__dict__["privilege"] = privilege
        super(Privileges, __self__).__init__(
            'onelogin:index/privileges:Privileges',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            privilege: Optional[pulumi.Input[pulumi.InputType['PrivilegesPrivilegeArgs']]] = None) -> 'Privileges':
        """
        Get an existing Privileges resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PrivilegesState.__new__(_PrivilegesState)

        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["privilege"] = privilege
        return Privileges(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def privilege(self) -> pulumi.Output['outputs.PrivilegesPrivilege']:
        return pulumi.get(self, "privilege")

